# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/request_base_dto'
require 'tg_mdk/mdk_dto/pay_now_id_constants'
require 'tg_mdk/mdk_dto/pay_now_id_param'
require 'tg_mdk/mdk_dto/charge_param'
require 'tg_mdk/mdk_dto/account_param'
require 'tg_mdk/mdk_dto/account_basic_param'
require 'tg_mdk/mdk_dto/card_param'
require 'tg_mdk/mdk_dto/recurring_charge_param'
require 'tg_mdk/mdk_dto/bank_account_param'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =PayNowIDリクエストDTOの親クラス
      #
      # @author:: VeriTrans Inc.
      #
      class AbstractPayNowIdRequestDto < Veritrans::Tercerog::Mdk::RequestBaseDto

        #
        # ===決済サービスタイプを取得する
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスコマンドを取得する
        # @return:: 決済サービスコマンド
        #
        def service_command
          @service_command = nil unless instance_variable_defined?(:@service_command)
          @service_command
        end

        #
        # ===会員IDを取得する
        # @return:: 会員ID
        #
        def account_id
          exist_account_param
          return pay_now_id_param.account_param.account_id
        end

        #
        # ===会員IDを設定する
        # 会員IDを指定します。
        # @param:: account_id 会員ID
        #
        def account_id=(account_id)
          exist_account_param
          pay_now_id_param.account_param.account_id = account_id
        end

        #
        # ===ワンタイムトークン種別を取得する
        # @return:: ワンタイムトークン種別
        #
        def onetime_token_type
          exist_account_param
          return pay_now_id_param.account_param.onetime_token_type
        end

        #
        # ===ワンタイムトークン種別を設定する
        # ワンタイムトークン種別を指定します。
        # @param:: onetime_token_type ワンタイムトークン種別
        #
        def onetime_token_type=(onetime_token_type)
          exist_account_param
          pay_now_id_param.account_param.onetime_token_type = onetime_token_type
        end

        #
        # ===元会員IDを取得する
        # @return:: 元会員ID
        #
        def original_account_id
          exist_account_param
          return pay_now_id_param.account_param.original_account_id
        end

        #
        # ===元会員IDを設定する
        # 元会員IDを指定します。
        # @param:: original_account_id 元会員ID
        #
        def original_account_id=(original_account_id)
          exist_account_param
          pay_now_id_param.account_param.original_account_id = original_account_id
        end

        #
        # ===PayNowIDを取得する
        # @return:: PayNowID
        #
        def pay_now_id
          exist_account_param
          return pay_now_id_param.account_param.pay_now_id
        end

        #
        # ===PayNowIDを設定する
        # PayNowIDを指定します。
        # @param:: pay_now_id PayNowID
        #
        def pay_now_id=(pay_now_id)
          exist_account_param
          pay_now_id_param.account_param.pay_now_id = pay_now_id
        end

        #
        # ===リクエスト項目を取得する
        # @return:: リクエスト項目
        #
        def trans_data
          exist_account_param
          return pay_now_id_param.account_param.trans_data
        end

        #
        # ===リクエスト項目を設定する
        # リクエスト項目を指定します。
        # @param:: trans_data リクエスト項目
        #
        def trans_data=(trans_data)
          exist_account_param
          pay_now_id_param.account_param.trans_data = trans_data
        end

        #
        # ===入会年月日を取得する
        # @return:: 入会年月日
        #
        def create_date
          exist_account_basic_param
          return pay_now_id_param.account_param.account_basic_param.create_date
        end

        #
        # ===入会年月日を設定する
        # 入会年月日を指定します。
        # @param:: create_date 入会年月日
        #
        def create_date=(create_date)
          exist_account_basic_param
          pay_now_id_param.account_param.account_basic_param.create_date = create_date
        end

        #
        # ===退会年月日を取得する
        # @return:: 退会年月日
        #
        def delete_date
          exist_account_basic_param
          return pay_now_id_param.account_param.account_basic_param.delete_date
        end

        #
        # ===退会年月日を設定する
        # 退会年月日を指定します。
        # @param:: delete_date 退会年月日
        #
        def delete_date=(delete_date)
          exist_account_basic_param
          pay_now_id_param.account_param.account_basic_param.delete_date = delete_date
        end

        #
        # ===強制退会フラグを取得する
        # @return:: 強制退会フラグ
        #
        def force_delete_date
          exist_account_basic_param
          return pay_now_id_param.account_param.account_basic_param.force_delete_date
        end

        #
        # ===強制退会フラグを設定する
        # 強制退会フラグを指定します。
        # @param:: force_delete_date 強制退会フラグ
        #
        def force_delete_date=(force_delete_date)
          exist_account_basic_param
          pay_now_id_param.account_param.account_basic_param.force_delete_date = force_delete_date
        end

        #
        # ===カード情報削除フラグを取得する
        # @return:: カード情報削除フラグ
        #
        def delete_card_info
          exist_account_basic_param
          return pay_now_id_param.account_param.account_basic_param.delete_card_info
        end

        #
        # ===カード情報削除フラグを設定する
        # カード情報削除フラグを指定します。
        # @param:: delete_card_info カード情報削除フラグ
        #
        def delete_card_info=(delete_card_info)
          exist_account_basic_param
          pay_now_id_param.account_param.account_basic_param.delete_card_info = delete_card_info
        end

        #
        # ===カード情報追加フラグを取得する
        # @return:: カード情報追加フラグ
        #
        def add_card_info
          exist_account_basic_param
          return pay_now_id_param.account_param.account_basic_param.add_card_info
        end

        #
        # ===カード情報追加フラグを設定する
        # カード情報追加フラグを指定します。
        # @param:: add_card_info カード情報追加フラグ
        #
        def add_card_info=(add_card_info)
          exist_account_basic_param
          pay_now_id_param.account_param.account_basic_param.add_card_info = add_card_info
        end

        #
        # ===元会員ID退会フラグを取得する
        # @return:: 元会員ID退会フラグ
        #
        def delete_original_account_id
          exist_account_basic_param
          return pay_now_id_param.account_param.account_basic_param.delete_original_account_id
        end

        #
        # ===元会員ID退会フラグを設定する
        # 元会員ID退会フラグを指定します。
        # @param:: delete_original_account_id 元会員ID退会フラグ
        #
        def delete_original_account_id=(delete_original_account_id)
          exist_account_basic_param
          pay_now_id_param.account_param.account_basic_param.delete_original_account_id = delete_original_account_id
        end

        #
        # ===標準カード限定フラグを取得する
        # @return:: 標準カード限定フラグ
        #
        def default_card_only
          exist_account_basic_param
          return pay_now_id_param.account_param.account_basic_param.default_card_only
        end

        #
        # ===標準カード限定フラグを設定する
        # 標準カード限定フラグを指定します。
        # @param:: default_card_only 標準カード限定フラグ
        #
        def default_card_only=(default_card_only)
          exist_account_basic_param
          pay_now_id_param.account_param.account_basic_param.default_card_only = default_card_only
        end

        #
        # ===洗替設定フラグを取得する
        # @return:: 洗替設定フラグ
        #
        def cleaning_config
          exist_account_basic_param
          return pay_now_id_param.account_param.account_basic_param.cleaning_config
        end

        #
        # ===洗替設定フラグを設定する
        # 洗替設定フラグを指定します。
        # @param:: cleaning_config 洗替設定フラグ
        #
        def cleaning_config=(cleaning_config)
          exist_account_basic_param
          pay_now_id_param.account_param.account_basic_param.cleaning_config = cleaning_config
        end

        #
        # ===カードIDを取得する
        # @return:: カードID
        #
        def card_id
          exist_card_param
          return pay_now_id_param.account_param.card_param.card_id
        end

        #
        # ===カードIDを設定する
        # カードIDを指定します。
        # @param:: card_id カードID
        #
        def card_id=(card_id)
          exist_card_param
          pay_now_id_param.account_param.card_param.card_id = card_id
        end

        #
        # ===標準カードフラグを取得する
        # @return:: 標準カードフラグ
        #
        def default_card
          exist_card_param
          return pay_now_id_param.account_param.card_param.default_card
        end

        #
        # ===標準カードフラグを設定する
        # 標準カードフラグを指定します。
        # @param:: default_card 標準カードフラグ
        #
        def default_card=(default_card)
          exist_card_param
          pay_now_id_param.account_param.card_param.default_card = default_card
        end

        #
        # ===標準カードIDを取得する
        # @return:: 標準カードID
        #
        def default_card_id
          exist_card_param
          return pay_now_id_param.account_param.card_param.default_card_id
        end

        #
        # ===標準カードIDを設定する
        # 標準カードIDを指定します。
        # @param:: default_card_id 標準カードID
        #
        def default_card_id=(default_card_id)
          exist_card_param
          pay_now_id_param.account_param.card_param.default_card_id = default_card_id
        end

        #
        # ===セキュリティコードを取得する
        # @return:: セキュリティコード
        #
        def security_code
          exist_card_param
          return pay_now_id_param.account_param.card_param.security_code
        end

        #
        # ===セキュリティコードを設定する
        # セキュリティコードを指定します。
        # @param:: security_code セキュリティコード
        #
        def security_code=(security_code)
          exist_card_param
          pay_now_id_param.account_param.card_param.security_code = security_code
        end

        #
        # ===洗替実施フラグを取得する
        # @return:: 洗替実施フラグ
        #
        def updater
          exist_card_param
          return pay_now_id_param.account_param.card_param.updater
        end

        #
        # ===洗替実施フラグを設定する
        # 洗替実施フラグを指定します。
        # @param:: updater 洗替実施フラグ
        #
        def updater=(updater)
          exist_card_param
          pay_now_id_param.account_param.card_param.updater = updater
        end

        #
        # ===カード番号を取得する
        # @return:: カード番号
        #
        def card_number
          exist_card_param
          return pay_now_id_param.account_param.card_param.card_number
        end

        #
        # ===カード番号を設定する
        # カード番号を指定します。
        # @param:: card_number カード番号
        #
        def card_number=(card_number)
          exist_card_param
          pay_now_id_param.account_param.card_param.card_number = card_number
        end

        #
        # ===有効期限を取得する
        # @return:: 有効期限
        #
        def card_expire
          exist_card_param
          return pay_now_id_param.account_param.card_param.card_expire
        end

        #
        # ===有効期限を設定する
        # 有効期限を指定します。
        # @param:: card_expire 有効期限
        #
        def card_expire=(card_expire)
          exist_card_param
          pay_now_id_param.account_param.card_param.card_expire = card_expire
        end

        #
        # ===カード保有者名を取得する
        # @return:: カード保有者名
        #
        def cardholder_name
          exist_card_param
          return pay_now_id_param.account_param.card_param.cardholder_name
        end

        #
        # ===カード保有者名を設定する
        # カード保有者名を指定します。
        # @param:: cardholder_name カード保有者名
        #
        def cardholder_name=(cardholder_name)
          exist_card_param
          pay_now_id_param.account_param.card_param.cardholder_name = cardholder_name
        end

        #
        # ===トークンを取得する
        # @return:: トークン
        #
        def token
          exist_card_param
          pay_now_id_param.account_param.card_param.token
        end

        #
        # ===トークンを設定する
        # @param:: token トークン
        #
        def token=(token)
          exist_card_param
          pay_now_id_param.account_param.card_param.token = token
        end

        #
        # ===カード番号マスクタイプを取得する
        # @return:: カード番号マスクタイプ
        #
        def card_number_mask_type
          exist_card_param
          pay_now_id_param.account_param.card_param.card_number_mask_type
        end

        #
        # ===カード番号マスクタイプを設定する
        # @param:: card_number_mask_type カード番号マスクタイプ
        #
        def card_number_mask_type=(card_number_mask_type)
          exist_card_param
          pay_now_id_param.account_param.card_param.card_number_mask_type = card_number_mask_type
        end

        #
        # ===与信実施フラグを取得する
        # @return:: 与信実施フラグ
        #
        def with_authorize
          exist_card_param
          pay_now_id_param.account_param.card_param.with_authorize
        end

        #
        # ===与信実施フラグを設定する
        # @param:: with_authorize 与信実施フラグ
        #
        def with_authorize=(with_authorize)
          exist_card_param
          pay_now_id_param.account_param.card_param.with_authorize = with_authorize
        end

        #
        # ===課金グループIDを取得する
        # @return:: 課金グループID
        #
        def group_id
          if self.service_type == Veritrans::Tercerog::Mdk::PayNowIdConstants::SERVICE_TYPE_ACCOUNT \
          || self.service_type == Veritrans::Tercerog::Mdk::PayNowIdConstants::SERVICE_TYPE_RECURRING
            exist_recurring_charge_param
            pay_now_id_param.account_param.recurring_charge_param.group_id

          elsif self.service_type == Veritrans::Tercerog::Mdk::PayNowIdConstants::SERVICE_TYPE_CHARGE
            exist_charge_param
            pay_now_id_param.charge_param.group_id
          end
        end

        #
        # ===課金グループIDを設定する
        # 課金グループIDを指定します。
        # @param:: group_id 課金グループID
        #
        def group_id=(group_id)
          if self.service_type == Veritrans::Tercerog::Mdk::PayNowIdConstants::SERVICE_TYPE_ACCOUNT \
          || self.service_type == Veritrans::Tercerog::Mdk::PayNowIdConstants::SERVICE_TYPE_RECURRING
            exist_recurring_charge_param
            pay_now_id_param.account_param.recurring_charge_param.group_id = group_id

          elsif self.service_type == Veritrans::Tercerog::Mdk::PayNowIdConstants::SERVICE_TYPE_CHARGE
            exist_charge_param
            pay_now_id_param.charge_param.group_id = group_id
          end
        end

        #
        # ===課金開始日を取得する
        # @return:: 課金開始日
        #
        def start_date
          exist_recurring_charge_param
          return pay_now_id_param.account_param.recurring_charge_param.start_date
        end

        #
        # ===課金開始日を設定する
        # 課金開始日を指定します。
        # @param:: start_date 課金開始日
        #
        def start_date=(start_date)
          exist_recurring_charge_param
          pay_now_id_param.account_param.recurring_charge_param.start_date = start_date
        end

        #
        # ===課金終了日を取得する
        # @return:: 課金終了日
        #
        def end_date
          exist_recurring_charge_param
          return pay_now_id_param.account_param.recurring_charge_param.end_date
        end

        #
        # ===課金終了日を設定する
        # 終了開始日を指定します。
        # @param:: end_date 課金終了日
        #
        def end_date=(end_date)
          exist_recurring_charge_param
          pay_now_id_param.account_param.recurring_charge_param.end_date = end_date
        end

        #
        # ===次回課金終了フラグを取得する
        # @return:: 次回課金終了フラグ
        #
        def final_charge
          exist_recurring_charge_param
          return pay_now_id_param.account_param.recurring_charge_param.final_charge
        end

        #
        # ===次回課金終了フラグを設定する
        # 次回課金終了フラグを指定します。
        # @param:: final_charge 次回課金終了フラグ
        #
        def final_charge=(final_charge)
          exist_recurring_charge_param
          pay_now_id_param.account_param.recurring_charge_param.final_charge = final_charge
        end

        #
        # ===継続課金用メモ1を取得する
        # @return:: 継続課金用メモ1
        #
        def recurring_memo1
          exist_recurring_charge_param
          return pay_now_id_param.account_param.recurring_charge_param.recurring_memo1
        end

        #
        # ===継続課金用メモ1を設定する
        # 継続課金用メモ1を指定します。
        # @param:: recurring_memo1 継続課金用メモ1
        #
        def recurring_memo1=(recurring_memo1)
          exist_recurring_charge_param
          pay_now_id_param.account_param.recurring_charge_param.recurring_memo1 = recurring_memo1
        end

        #
        # ===継続課金用メモ2を取得する
        # @return:: 継続課金用メモ2
        #
        def recurring_memo2
          exist_recurring_charge_param
          return pay_now_id_param.account_param.recurring_charge_param.recurring_memo2
        end

        #
        # ===継続課金用メモ2を設定する
        # 継続課金用メモ2を指定します。
        # @param:: recurring_memo2 継続課金用メモ2
        #
        def recurring_memo2=(recurring_memo2)
          exist_recurring_charge_param
          pay_now_id_param.account_param.recurring_charge_param.recurring_memo2 = recurring_memo2
        end

        #
        # ===継続課金用メモ3を取得する
        # @return:: 継続課金用メモ3
        #
        def recurring_memo3
          exist_recurring_charge_param
          return pay_now_id_param.account_param.recurring_charge_param.recurring_memo3
        end

        #
        # ===継続課金用メモ3を設定する
        # 継続課金用メモ3を指定します。
        # @param:: recurring_memo3 継続課金用メモ3
        #
        def recurring_memo3=(recurring_memo3)
          exist_recurring_charge_param
          pay_now_id_param.account_param.recurring_charge_param.recurring_memo3 = recurring_memo3
        end

        #
        # ===課金オプション利用フラグを取得する
        # @return:: 課金オプション利用フラグ
        #
        def use_charge_option
          exist_recurring_charge_param
          return pay_now_id_param.account_param.recurring_charge_param.use_charge_option
        end

        #
        # ===課金オプション利用フラグを設定する
        # 課金オプション利用フラグを指定します。
        # @param:: use_charge_option 課金オプション利用フラグ
        #
        def use_charge_option=(use_charge_option)
          exist_recurring_charge_param
          pay_now_id_param.account_param.recurring_charge_param.use_charge_option = use_charge_option
        end

        #
        # ===都度/初回課金金額を取得する
        # @return:: 都度/初回課金金額
        #
        def one_time_amount
          if self.service_type == Veritrans::Tercerog::Mdk::PayNowIdConstants::SERVICE_TYPE_ACCOUNT \
          || self.service_type == Veritrans::Tercerog::Mdk::PayNowIdConstants::SERVICE_TYPE_RECURRING
            exist_recurring_charge_param
            pay_now_id_param.account_param.recurring_charge_param.one_time_amount

          elsif self.service_type == Veritrans::Tercerog::Mdk::PayNowIdConstants::SERVICE_TYPE_CHARGE
            exist_charge_param
            pay_now_id_param.charge_param.one_time_amount
          end
        end

        #
        # ===都度/初回課金金額を設定する
        # 都度/初回課金金額を指定します。
        # @param:: one_time_amount 都度/初回課金金額
        #
        def one_time_amount=(one_time_amount)
          if self.service_type == Veritrans::Tercerog::Mdk::PayNowIdConstants::SERVICE_TYPE_ACCOUNT \
          || self.service_type == Veritrans::Tercerog::Mdk::PayNowIdConstants::SERVICE_TYPE_RECURRING
            exist_recurring_charge_param
            pay_now_id_param.account_param.recurring_charge_param.one_time_amount = one_time_amount

          elsif self.service_type == Veritrans::Tercerog::Mdk::PayNowIdConstants::SERVICE_TYPE_CHARGE
            exist_charge_param
            pay_now_id_param.charge_param.one_time_amount = one_time_amount
          end
        end

        #
        # ===継続課金金額を取得する
        # @return:: 継続課金金額
        #
        def amount
          if self.service_type == Veritrans::Tercerog::Mdk::PayNowIdConstants::SERVICE_TYPE_ACCOUNT \
          || self.service_type == Veritrans::Tercerog::Mdk::PayNowIdConstants::SERVICE_TYPE_RECURRING
            exist_recurring_charge_param
            pay_now_id_param.account_param.recurring_charge_param.amount

          elsif self.service_type == Veritrans::Tercerog::Mdk::PayNowIdConstants::SERVICE_TYPE_CHARGE
            exist_charge_param
            pay_now_id_param.charge_param.amount
          end
        end

        #
        # ===継続課金金額を設定する
        # 継続課金金額を指定します。
        # @param:: amount 継続課金金額
        #
        def amount=(amount)
          if self.service_type == Veritrans::Tercerog::Mdk::PayNowIdConstants::SERVICE_TYPE_ACCOUNT \
          || self.service_type == Veritrans::Tercerog::Mdk::PayNowIdConstants::SERVICE_TYPE_RECURRING
            exist_recurring_charge_param
            pay_now_id_param.account_param.recurring_charge_param.amount = amount

          elsif self.service_type == Veritrans::Tercerog::Mdk::PayNowIdConstants::SERVICE_TYPE_CHARGE
            exist_charge_param
            pay_now_id_param.charge_param.amount = amount
          end
        end

        #
        # ===売上日を取得する
        # @return:: 売上日
        #
        def sales_day
          if self.service_type == Veritrans::Tercerog::Mdk::PayNowIdConstants::SERVICE_TYPE_ACCOUNT \
          || self.service_type == Veritrans::Tercerog::Mdk::PayNowIdConstants::SERVICE_TYPE_RECURRING
            exist_recurring_charge_param
            pay_now_id_param.account_param.recurring_charge_param.sales_day

          elsif self.service_type == Veritrans::Tercerog::Mdk::PayNowIdConstants::SERVICE_TYPE_CHARGE
            exist_charge_param
            pay_now_id_param.charge_param.sales_day
          end
        end

        #
        # ===売上日を設定する
        # 売上日を指定します。
        # @param:: sales_day 売上日
        #
        def sales_day=(sales_day)
          if self.service_type == Veritrans::Tercerog::Mdk::PayNowIdConstants::SERVICE_TYPE_ACCOUNT \
          || self.service_type == Veritrans::Tercerog::Mdk::PayNowIdConstants::SERVICE_TYPE_RECURRING
            exist_recurring_charge_param
            pay_now_id_param.account_param.recurring_charge_param.sales_day = sales_day

          elsif self.service_type == Veritrans::Tercerog::Mdk::PayNowIdConstants::SERVICE_TYPE_CHARGE
            exist_charge_param
            pay_now_id_param.charge_param.sales_day = sales_day
          end
        end

        #
        # ===仕向先会社コードを取得する
        # @return:: 仕向先会社コード
        #
        def acquire_code
          if self.service_type == Veritrans::Tercerog::Mdk::PayNowIdConstants::SERVICE_TYPE_ACCOUNT \
          || self.service_type == Veritrans::Tercerog::Mdk::PayNowIdConstants::SERVICE_TYPE_RECURRING
            exist_recurring_charge_param
            pay_now_id_param.account_param.recurring_charge_param.acquire_code

          elsif self.service_type == Veritrans::Tercerog::Mdk::PayNowIdConstants::SERVICE_TYPE_CHARGE
            exist_charge_param
            pay_now_id_param.charge_param.acquire_code
          end
        end

        #
        # ===仕向先会社コードを設定する
        # 仕向先会社コードを指定します。
        # @param:: acquire_code 仕向先会社コード
        #
        def acquire_code=(acquire_code)
          if self.service_type == Veritrans::Tercerog::Mdk::PayNowIdConstants::SERVICE_TYPE_ACCOUNT \
          || self.service_type == Veritrans::Tercerog::Mdk::PayNowIdConstants::SERVICE_TYPE_RECURRING
            exist_recurring_charge_param
            pay_now_id_param.account_param.recurring_charge_param.acquire_code = acquire_code

          elsif self.service_type == Veritrans::Tercerog::Mdk::PayNowIdConstants::SERVICE_TYPE_CHARGE
            exist_charge_param
            pay_now_id_param.charge_param.acquire_code = acquire_code
          end
        end

        #
        # ===金融機関コードを取得する
        # @return:: 金融機関コード
        #
        def bank_code
          exist_bank_account_param
          return pay_now_id_param.account_param.bank_account_param.bank_code
        end

        #
        # ===金融機関コードを設定する
        # 金融機関コードを指定します。
        # @param:: bank_code 金融機関コード
        #
        def bank_code=(bank_code)
          exist_bank_account_param
          pay_now_id_param.account_param.bank_account_param.bank_code = bank_code
        end

        #
        # ===支店コードを取得する
        # @return:: 支店コード
        #
        def branch_code
          exist_bank_account_param
          return pay_now_id_param.account_param.bank_account_param.branch_code
        end

        #
        # ===支店コードを設定する
        # 支店コードを指定します。
        # @param:: branch_code 支店コード
        #
        def branch_code=(branch_code)
          exist_bank_account_param
          pay_now_id_param.account_param.bank_account_param.branch_code = branch_code
        end

        # ===口座種別を取得する
        # @return:: 口座種別
        #
        def account_type
          exist_bank_account_param
          return pay_now_id_param.account_param.bank_account_param.account_type
        end

        #
        # ===口座種別を設定する
        # 口座種別を指定します。
        # @param:: account_type 口座種別
        #
        def account_type=(account_type)
          exist_bank_account_param
          pay_now_id_param.account_param.bank_account_param.account_type = account_type
        end

        #
        # ===口座番号を取得する
        # @return:: 口座番号
        #
        def account_number
          exist_bank_account_param
          return pay_now_id_param.account_param.bank_account_param.account_number
        end

        #
        # ===口座番号を設定する
        # 口座番号を指定します。
        # @param:: account_number 口座番号
        #
        def account_number=(account_number)
          exist_bank_account_param
          pay_now_id_param.account_param.bank_account_param.account_number = account_number
        end

        #
        # ===口座管理方式を取得する
        # @return:: 口座管理方式
        #
        def account_manage_type
          exist_bank_account_param
          return pay_now_id_param.account_param.bank_account_param.account_manage_type
        end

        #
        # ===口座管理方式を設定する
        # 口座管理方式を指定します。
        # @param:: account_manage_type 口座管理方式
        #
        def account_manage_type=(account_manage_type)
          exist_bank_account_param
          pay_now_id_param.account_param.bank_account_param.account_manage_type = account_manage_type
        end

        #
        # ===銀行口座関連付け拒否フラグを取得する
        # @return:: 銀行口座関連付け拒否フラグ
        #
        def reject_bank_account
          exist_bank_account_param
          return pay_now_id_param.account_param.bank_account_param.reject_bank_account
        end

        #
        # ===銀行口座関連付け拒否フラグを設定する
        # 銀行口座関連付け拒否フラグを指定します。
        # @param:: reject_bank_account 銀行口座関連付け拒否フラグ
        #
        def reject_bank_account=(reject_bank_account)
          exist_bank_account_param
          pay_now_id_param.account_param.bank_account_param.reject_bank_account = reject_bank_account
        end

        #
        # ===元取引IDを取得する
        # @return:: 元取引ID
        #
        def original_order_id
          exist_order_param
          pay_now_id_param.order_param.original_order_id
        end

        #
        # ===元取引IDを設定する
        # 元取引IDを指定します。
        # @param:: original_order_id 元取引ID
        #
        def original_order_id=(original_order_id)
          exist_order_param
          pay_now_id_param.order_param.original_order_id = original_order_id
        end

        #
        # ===洗替実施マーチャントIDを取得する
        # @return:: 洗替実施マーチャントID
        #
        def cleaning_merchant_id
          exist_order_param
          pay_now_id_param.order_param.cleaning_merchant_id
        end

        #
        # ===洗替実施マーチャントIDを設定する
        # 洗替実施マーチャントIDを指定します。
        # @param:: cleaning_merchant_id 洗替実施マーチャントID
        #
        def cleaning_merchant_id=(cleaning_merchant_id)
          exist_order_param
          pay_now_id_param.order_param.cleaning_merchant_id = cleaning_merchant_id
        end

        #
        # ===課金グループ名を取得する
        # @return:: 課金グループ名
        #
        def group_name
          exist_charge_param
          pay_now_id_param.charge_param.group_name
        end

        #
        # ===課金グループ名を設定する
        # 課金グループ名を指定します。
        # @param:: group_name 課金グループ名
        #
        def group_name=(group_name)
          exist_charge_param
          pay_now_id_param.charge_param.group_name = group_name
        end

        #
        # ===課金スタイル区分を取得する
        # @return:: 課金スタイル区分
        #
        def type
          exist_charge_param
          pay_now_id_param.charge_param.type
        end

        #
        # ===課金スタイル区分を設定する
        # 課金スタイル区分を指定します。
        # @param:: type 課金スタイル区分
        #
        def type=(type)
          exist_charge_param
          pay_now_id_param.charge_param.type = type
        end

        #
        # ===課金日取扱区分を取得する
        # @return:: 課金日取扱区分
        #
        def charge_type
          exist_charge_param
          pay_now_id_param.charge_param.charge_type
        end

        #
        # ===課金日取扱区分を設定する
        # 課金日取扱区分を指定します。
        # @param:: charge_type 課金日取扱区分
        #
        def charge_type=(charge_type)
          exist_charge_param
          pay_now_id_param.charge_param.charge_type = charge_type
        end

        #
        # ===継続課金スケジュールを取得する
        # @return:: 継続課金スケジュール
        #
        def schedule
          exist_charge_param
          pay_now_id_param.charge_param.schedule
        end

        #
        # ===継続課金スケジュールを設定する
        # 継続課金スケジュールを指定します。
        # @param:: schedule 継続課金スケジュール
        #
        def schedule=(schedule)
          exist_charge_param
          pay_now_id_param.charge_param.schedule = schedule
        end

        #
        # ===タンキングフラグを取得する
        # @return:: タンキングフラグ
        #
        def tanking
          pay_now_id_param.tanking
        end

        #
        # ===タンキングフラグを設定する
        # タンキングフラグを指定します。
        # @param:: tanking タンキングフラグ
        #
        def tanking=(tanking)
          pay_now_id_param.tanking = tanking
        end

        private

        #
        # ===PayNowIdParamを取得する
        # @return:: PayNowIdParam
        #
        def pay_now_id_param
          @pay_now_id_param = nil unless instance_variable_defined?(:@pay_now_id_param)
          if @pay_now_id_param.nil?
            @pay_now_id_param = PayNowIdParam.new
          end
          return @pay_now_id_param
        end

        #
        # ===account_paramが設定されているか判定する
        # account_paramが設定されているか判定します。
        # 設定されていない場合はインスタンスを生成し、pay_now_id_paramに設定します。
        #
        def exist_account_param
          if pay_now_id_param.account_param.nil?
            pay_now_id_param.account_param = AccountParam.new
          end
        end

        #
        # ===charge_paramが設定されているか判定する
        # charge_paramが設定されているか判定します。
        # 設定されていない場合はインスタンスを生成し、pay_now_id_paramに設定します。
        #
        def exist_charge_param
          if pay_now_id_param.charge_param.nil?
            pay_now_id_param.charge_param = ChargeParam.new
          end
        end

        #
        # ===account_basic_paramが設定されているか判定する
        # account_basic_paramが設定されているか判定します。
        # 設定されていない場合はインスタンスを生成し、account_paramに設定します。
        #
        def exist_account_basic_param
          exist_account_param
          if pay_now_id_param.account_param.account_basic_param.nil?
            pay_now_id_param.account_param.account_basic_param = AccountBasicParam.new
          end
        end

        #
        # ===card_paramが設定されているか判定する
        # card_paramが設定されているか判定します。
        # 設定されていない場合はインスタンスを生成し、account_paramに設定します。
        #
        def exist_card_param
          exist_account_param
          if pay_now_id_param.account_param.card_param.nil?
            pay_now_id_param.account_param.card_param = CardParam.new
          end
        end

        #
        # ===recurring_charge_paramが設定されているか判定する
        # recurring_charge_paramが設定されているか判定します。
        # 設定されていない場合はインスタンスを生成し、account_paramに設定します。
        #
        def exist_recurring_charge_param
          exist_account_param
          if pay_now_id_param.account_param.recurring_charge_param.nil?
            pay_now_id_param.account_param.recurring_charge_param = RecurringChargeParam.new
          end
        end

        #
        # ===bank_account_paramが設定されているか判定する
        # bank_account_paramが設定されているか判定します。
        # 設定されていない場合はインスタンスを生成し、account_paramに設定します。
        #
        def exist_bank_account_param
          exist_account_param
          if pay_now_id_param.account_param.bank_account_param.nil?
            pay_now_id_param.account_param.bank_account_param = BankAccountParam.new
          end
        end

        #
        # ===order_paramが設定されているか判定する
        # order_paramが設定されているか判定します。
        # 設定されていない場合はインスタンスを生成し、pay_now_id_paramに設定します。
        #
        def exist_order_param
          if pay_now_id_param.order_param.nil?
            pay_now_id_param.order_param = OrderParam.new
          end
        end

      end
    end
  end
end
