# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/request_base_dto'
require 'tg_mdk/mdk_dto/pay_now_id_param'
require 'tg_mdk/mdk_dto/account_param'
require 'tg_mdk/mdk_dto/account_basic_param'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済の親クラス
      #
      # @author:: VeriTrans Inc.
      #
      class AbstractPaymentRequestDto < Veritrans::Tercerog::Mdk::RequestBaseDto

        #
        # ===取引メモ1を取得する
        # @return:: 取引メモ1
        #
        def memo1
          pay_now_id_param.memo1
        end

        #
        # ===取引メモ1を設定する
        # 取引メモ1を指定します。
        # @param:: memo1 取引メモ1
        #
        def memo1=(memo1)
          pay_now_id_param.memo1 = memo1
        end

        #
        # ===取引メモ2を取得する
        # @return:: 取引メモ2
        #
        def memo2
          pay_now_id_param.memo2
        end

        #
        # ===取引メモ2を設定する
        # 取引メモ2を指定します。
        # @param:: memo2 取引メモ1
        #
        def memo2=(memo2)
          pay_now_id_param.memo2 = memo2
        end

        #
        # ===取引メモ3を取得する
        # @return:: 取引メモ3
        #
        def memo3
          pay_now_id_param.memo3
        end

        #
        # ===取引メモ3を設定する
        # 取引メモ3を指定します。
        # @param:: memo3 取引メモ1
        #
        def memo3=(memo3)
          pay_now_id_param.memo3 = memo3
        end

        #
        # ===キー情報を取得する
        # @return:: キー情報
        #
        def free_key
          pay_now_id_param.free_key
        end

        #
        # ===キー情報を設定する
        # キー情報を指定します。
        # @param:: free_key キー情報
        #
        def free_key=(free_key)
          pay_now_id_param.free_key = free_key
        end

        #
        # ===レシートデータを取得する
        # @return:: レシートデータ
        #
        def receipt_data
          pay_now_id_param.receipt_data
        end

        #
        # ===レシートデータを設定する
        # レシートデータを指定します。
        # @param:: receipt_data レシートデータ
        #
        def receipt_data=(receipt_data)
          pay_now_id_param.receipt_data = receipt_data
        end

        #
        # ===会員IDを取得する
        # @return:: 会員ID
        #
        def account_id
          exist_account_param
          return pay_now_id_param.account_param.account_id
        end

        #
        # ===会員IDを設定する
        # 会員IDを指定します。
        # @param:: account_id 会員ID
        #
        def account_id=(account_id)
          exist_account_param
          pay_now_id_param.account_param.account_id = account_id
        end

        #
        # ===入会年月日を取得する
        # @return:: 入会年月日
        #
        def create_date
          exist_account_basic_param
          return pay_now_id_param.account_param.account_basic_param.create_date
        end

        #
        # ===入会年月日を設定する
        # 入会年月日を指定します。
        # @param:: create_date 入会年月日
        #
        def create_date=(create_date)
          exist_account_basic_param
          pay_now_id_param.account_param.account_basic_param.create_date = create_date
        end

        private

        #
        # ===PayNowIdParamを取得する
        # @return:: PayNowIdParam
        #
        def pay_now_id_param
          @pay_now_id_param = nil unless instance_variable_defined?(:@pay_now_id_param)
          if @pay_now_id_param.nil?
            @pay_now_id_param = PayNowIdParam.new
          end
          return @pay_now_id_param
        end

        #
        # ===account_paramが設定されているか判定する
        # account_paramが設定されているか判定します。
        # 設定されていない場合はインスタンスを生成し、pay_now_id_paramに設定します。
        #
        def exist_account_param
          if pay_now_id_param.account_param.nil?
            pay_now_id_param.account_param = AccountParam.new
          end
        end

        #
        # ===account_basic_paramが設定されているか判定する
        # account_basic_paramが設定されているか判定します。
        # 設定されていない場合はインスタンスを生成し、account_paramに設定します。
        #
        def exist_account_basic_param
          exist_account_param
          if pay_now_id_param.account_param.account_basic_param.nil?
            pay_now_id_param.account_param.account_basic_param = AccountBasicParam.new
          end
        end

      end
    end
  end
end
