# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/abstract_payment_request_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：Amazonpay、コマンド名：承諾情報更新の要求Dtoクラス
      #
      # @author:: VeriTrans Inc.
      #
      class AmazonpayUpdateConsentRequestDto < Veritrans::Tercerog::Mdk::AbstractPaymentRequestDto

        #
        # ===コンストラクタ
        #
        def initialize
          @service_type = SERVICE_TYPE
          @service_command = SERVICE_COMMAND
        end


        #
        # 決済サービスタイプ
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_TYPE = "amazonpay"

        #
        # 決済サービスコマンド
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_COMMAND = "UpdateConsent"


        #
        # ===決済サービスタイプを取得する
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスコマンドを取得する
        # @return:: 決済サービスコマンド
        #
        def service_command
          @service_command = nil unless instance_variable_defined?(:@service_command)
          @service_command
        end

        #
        # ===取引IDを取得する
        # @return:: 取引ID
        #
        def order_id
          @order_id = nil unless instance_variable_defined?(:@order_id)
          @order_id
        end

        #
        # ===取引IDを設定する
        # 随時決済を申し込んだ際の取引IDを指定します。
        # @param:: order_id 取引ID
        #
        def order_id=(order_id)
          @order_id = order_id
        end

        #
        # ===決済金額を取得する
        # @return:: 決済金額
        #
        def amount
          @amount = nil unless instance_variable_defined?(:@amount)
          @amount
        end

        #
        # ===決済金額を設定する
        # 変更後の決済金額を指定します。
        # - 1 以上かつ 100000(6桁) 以下
        # @param:: amount 決済金額
        #
        def amount=(amount)
          @amount = amount
        end

        #
        # ===頻度（単位）を取得する
        # @return:: 頻度（単位）
        #
        def frequency_unit
          @frequency_unit = nil unless instance_variable_defined?(:@frequency_unit)
          @frequency_unit
        end

        #
        # ===頻度（単位）を設定する
        # 変更後の随時決済の頻度の単位（例：2週間毎であれば、単位はWeek、値は2）
        # "Year"：年
        # "Month"：月
        # "Week"：週
        # "Day"：日
        # @param:: frequency_unit 頻度（単位）
        #
        def frequency_unit=(frequency_unit)
          @frequency_unit = frequency_unit
        end

        #
        # ===頻度（値）を取得する
        # @return:: 頻度（値）
        #
        def frequency_value
          @frequency_value = nil unless instance_variable_defined?(:@frequency_value)
          @frequency_value
        end

        #
        # ===頻度（値）を設定する
        # 変更後の随時決済の頻度の値（例：2週間毎であれば、単位はWeek、値は2）
        # - 頻度（単位）毎に設定できる範囲が異なります。
        # "Year"：1のみ
        # "Month"：1～12
        # "Week"：1～52
        # "Day"：1～365
        # @param:: frequency_value 頻度（値）
        #
        def frequency_value=(frequency_value)
          @frequency_value = frequency_value
        end

        #
        # ===プラットフォームIDを取得する
        # @return:: プラットフォームID
        #
        def platform_id
          @platform_id = nil unless instance_variable_defined?(:@platform_id)
          @platform_id
        end

        #
        # ===プラットフォームIDを設定する
        # Amazonから指定のあった場合のみ設定する予定の項目
        # - 最大:21byte
        # @param:: platform_id プラットフォームID
        #
        def platform_id=(platform_id)
          @platform_id = platform_id
        end

        #
        # ===注文説明を取得する
        # @return:: 注文説明
        #
        def note_to_buyer
          @note_to_buyer = nil unless instance_variable_defined?(:@note_to_buyer)
          @note_to_buyer
        end

        #
        # ===注文説明を設定する
        # 変更後の購入者のメールに表示される注文の説明
        # - 最大:255文字
        # @param:: note_to_buyer 注文説明
        #
        def note_to_buyer=(note_to_buyer)
          @note_to_buyer = note_to_buyer
        end


      end
    end
  end
end
