# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/abstract_payment_request_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：bankpay、コマンド名：口座入力情報取得の要求Dtoクラス
      #
      # @author:: VeriTrans Inc.
      #
      class BankpayPrepareAccountAddRequestDto < Veritrans::Tercerog::Mdk::AbstractPaymentRequestDto

        #
        # ===コンストラクタ
        #
        def initialize
          @service_type = SERVICE_TYPE
          @service_command = SERVICE_COMMAND
        end


        #
        # 決済サービスタイプ
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_TYPE = "bankpay"

        #
        # 決済サービスコマンド
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_COMMAND = "PrepareAccountAdd"


        #
        # ===決済サービスタイプを取得する
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスコマンドを取得する
        # @return:: 決済サービスコマンド
        #
        def service_command
          @service_command = nil unless instance_variable_defined?(:@service_command)
          @service_command
        end

        #
        # ===サービスオプションタイプを取得する
        # @return:: サービスオプションタイプ
        #
        def service_option_type
          @service_option_type = nil unless instance_variable_defined?(:@service_option_type)
          @service_option_type
        end

        #
        # ===サービスオプションタイプを設定する
        # - "online":オンライン決済
        # @param:: service_option_type サービスオプションタイプ
        #
        def service_option_type=(service_option_type)
          @service_option_type = service_option_type
        end

        #
        # ===会員IDを取得する
        # @return:: 会員ID
        #
        def member_id
          @member_id = nil unless instance_variable_defined?(:@member_id)
          @member_id
        end

        #
        # ===会員IDを設定する
        # 口座登録対象の会員IDを指定します。
        # @param:: member_id 会員ID
        #
        def member_id=(member_id)
          @member_id = member_id
        end

        #
        # ===口座IDを取得する
        # @return:: 口座ID
        #
        def account_id
          @account_id = nil unless instance_variable_defined?(:@account_id)
          @account_id
        end

        #
        # ===口座IDを設定する
        # - マーチャント側で口座を一意に表す口座IDを指定します。
        # - 口座ごとに一意である必要があります。
        # - 半角英数、“-”（ハイフン）、“_”（アンダースコア）も使用可能です。
        # @param:: account_id 口座ID
        #
        def account_id=(account_id)
          @account_id = account_id
        end

        #
        # ===決済完了時URLを取得する
        # @return:: 決済完了時URL
        #
        def success_url
          @success_url = nil unless instance_variable_defined?(:@success_url)
          @success_url
        end

        #
        # ===決済完了時URLを設定する
        # 口座登録完了後に、店舗側サイトに画面遷移を戻すためのURLを指定します。
        # 
        # ※未指定の場合は、MAP（Merchant Administrator Portal）から登録申請した値を使用。
        # @param:: success_url 決済完了時URL
        #
        def success_url=(success_url)
          @success_url = success_url
        end

        #
        # ===決済エラー時URLを取得する
        # @return:: 決済エラー時URL
        #
        def error_url
          @error_url = nil unless instance_variable_defined?(:@error_url)
          @error_url
        end

        #
        # ===決済エラー時URLを設定する
        # 口座登録エラー時に、店舗側サイトに画面遷移を戻すためのURLを指定します。
        # 
        # ※未指定の場合は、MAP（Merchant Administrator Portal）から登録申請した値を使用。
        # @param:: error_url 決済エラー時URL
        #
        def error_url=(error_url)
          @error_url = error_url
        end

        #
        # ===プッシュ先URLを取得する
        # @return:: プッシュ先URL
        #
        def push_url
          @push_url = nil unless instance_variable_defined?(:@push_url)
          @push_url
        end

        #
        # ===プッシュ先URLを設定する
        # プッシュURLを指定します。
        # 
        # ※未指定の場合は、MAP（Merchant Administrator Portal）から登録申請した値を使用。
        # @param:: push_url プッシュ先URL
        #
        def push_url=(push_url)
          @push_url = push_url
        end

        #
        # ===銀行コードを取得する
        # @return:: 銀行コード
        #
        def bank_code
          @bank_code = nil unless instance_variable_defined?(:@bank_code)
          @bank_code
        end

        #
        # ===銀行コードを設定する
        # 登録口座の銀行コードを入力します。
        # @param:: bank_code 銀行コード
        #
        def bank_code=(bank_code)
          @bank_code = bank_code
        end


      end
    end
  end
end
