# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/abstract_payment_credit_request_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：カード、コマンド名：不正検知のみ申込の要求Dtoクラス
      #
      # @author:: VeriTrans Inc.
      #
      class CardNoAuthorizeFraudDetectionRequestDto < Veritrans::Tercerog::Mdk::AbstractPaymentCreditRequestDto

        #
        # ===コンストラクタ
        #
        def initialize
          @service_type = SERVICE_TYPE
          @service_command = SERVICE_COMMAND
          @card_number = "4111111111111111"
          @card_expire = "12/50"
          @fraud_detection_v2_request = Veritrans::Tercerog::Mdk::FraudDetectionV2RequestDto.new
          @fraud_detection_v2_request.fraud_detection_only = "true"
          @fraud_detection_v2_request.risk = Veritrans::Tercerog::Mdk::FraudDetectionV2RiskDto.new
          @fraud_detection_v2_request.risk.parameters = Veritrans::Tercerog::Mdk::FraudDetectionV2ParametersDto.new
          @fraud_detection_v2_request.risk.parameters.cust_verification = "true"
        end

        #
        # 決済サービスタイプ
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_TYPE = "card"

        #
        # 決済サービスコマンド
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_COMMAND = "Authorize"

        #
        # ===決済サービスタイプを取得する
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスコマンドを取得する
        # @return:: 決済サービスコマンド
        #
        def service_command
          @service_command = nil unless instance_variable_defined?(:@service_command)
          @service_command
        end

        #
        # ===取引IDを取得する
        # @return:: 取引ID
        #
        def order_id
          @order_id = nil unless instance_variable_defined?(:@order_id)
          @order_id
        end

        #
        # ===取引IDを設定する
        # - マーチャント側で取引を一意に表す注文管理IDを指定します。
        # - 申込処理ごとに一意である必要があります。
        # - 半角英数字、“-”（ハイフン）、“_”（アンダースコア）も使用可能です。
        # @param:: order_id 取引ID
        #
        def order_id=(order_id)
          @order_id = order_id
        end

        #
        # ===決済金額を取得する
        # @return:: 決済金額
        #
        def amount
          @amount = nil unless instance_variable_defined?(:@amount)
          @amount
        end

        #
        # ===決済金額を設定する
        # - 決済金額を指定します。
        # - 1 以上かつ 99999999 以下である必要があります。
        # @param:: amount 決済金額
        #
        def amount=(amount)
          @amount = amount
        end

        #
        # ===カード番号を取得する
        # @return:: カード番号
        #
        def card_number
          @card_number = nil unless instance_variable_defined?(:@card_number)
          @card_number
        end

        #
        # ===カード番号を設定する
        # - クレジットカード番号を指定します。
        # - 例） クレジットカード番号は19桁まで処理が可能。
        # - （ハイフンを含んでも含まなくても同様に処理が可能）
        # - 戻り値としては､上2桁/下4桁の計6桁が返ります。
        # @param:: card_number カード番号
        #
        def card_number=(card_number)
          @card_number = card_number
        end

        #
        # ===カード有効期限を取得する
        # @return:: カード有効期限
        #
        def card_expire
          @card_expire = nil unless instance_variable_defined?(:@card_expire)
          @card_expire
        end

        #
        # ===カード有効期限を設定する
        # - クレジットカードの有効期限を指定します。
        # - MM/YY （月 + "/" + 年）の形式
        # - 例） "11/09"
        # @param:: card_expire カード有効期限
        #
        def card_expire=(card_expire)
          @card_expire = card_expire
        end

        #
        # ===不正検知V2評価取引情報を取得する
        # @return:: 不正検知V2評価取引情報
        #
        def fraud_detection_v2_request
          @fraud_detection_v2_request = nil unless instance_variable_defined?(:@fraud_detection_v2_request)
          @fraud_detection_v2_request
        end

        #
        # ===拡張パラメータリストを取得する
        # @return:: 拡張パラメータリスト
        #
        def option_params
          @option_params = nil unless instance_variable_defined?(:@option_params)
          @option_params
        end

        #
        # ===拡張パラメータリストを設定する
        # @param:: option_params 拡張パラメータリスト
        #
        def option_params=(option_params)
          @option_params = option_params
        end

      end
    end
  end
end
