# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/abstract_payment_credit_request_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：カード、コマンド名：再申込の要求Dtoクラス
      #
      # @author:: VeriTrans Inc.
      #
      class CardReAuthorizeRequestDto < Veritrans::Tercerog::Mdk::AbstractPaymentCreditRequestDto

        #
        # ===コンストラクタ
        #
        def initialize
          @service_type = SERVICE_TYPE
          @service_command = SERVICE_COMMAND
        end

        #
        # 決済サービスタイプ
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_TYPE = "card"

        #
        # 決済サービスコマンド
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_COMMAND = "ReAuthorize"

        #
        # ===決済サービスタイプを取得する
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスコマンドを取得する
        # @return:: 決済サービスコマンド
        #
        def service_command
          @service_command = nil unless instance_variable_defined?(:@service_command)
          @service_command
        end

        #
        # ===取引IDを取得する
        # @return:: 取引ID
        #
        def order_id
          @order_id = nil unless instance_variable_defined?(:@order_id)
          @order_id
        end

        #
        # ===取引IDを設定する
        # - マーチャント側で取引を一意に表す注文管理IDを指定します。
        # - 申込処理ごとに一意である必要があります。
        # - 半角英数字、“-”（ハイフン）、“_”（アンダースコア）も使用可能です。
        # @param:: order_id 取引ID
        #
        def order_id=(order_id)
          @order_id = order_id
        end

        #
        # ===元取引IDを取得する
        # @return:: 元取引ID
        #
        def original_order_id
          @original_order_id = nil unless instance_variable_defined?(:@original_order_id)
          @original_order_id
        end

        #
        # ===元取引IDを設定する
        # - マーチャントで過去の取引を表す注文管理IDを指定します。
        # - 半角英数字、“-”（ハイフン）、“_”（アンダースコア）も使用可能です。
        # @param:: original_order_id 元取引ID
        #
        def original_order_id=(original_order_id)
          @original_order_id = original_order_id
        end

        #
        # ===決済金額を取得する
        # @return:: 決済金額
        #
        def amount
          @amount = nil unless instance_variable_defined?(:@amount)
          @amount
        end

        #
        # ===決済金額を設定する
        # - 決済金額を指定します。
        # - 1 以上かつ 99999999 以下である必要があります。
        # @param:: amount 決済金額
        #
        def amount=(amount)
          @amount = amount
        end

        #
        # ===カード番号を取得する
        # @return:: カード番号
        #
        def card_number
          @card_number = nil unless instance_variable_defined?(:@card_number)
          @card_number
        end

        #
        # ===カード番号を設定する
        # - クレジットカード番号を指定します。
        # - 例） クレジットカード番号は19桁まで処理が可能。
        # - （ハイフンを含んでも含まなくても同様に処理が可能）
        # - 戻り値としては､上2桁/下4桁の計6桁が返ります。
        # - ※ eLIOカードは、指定できません
        # @param:: card_number カード番号
        #
        def card_number=(card_number)
          @card_number = card_number
        end

        #
        # ===カード有効期限を取得する
        # @return:: カード有効期限
        #
        def card_expire
          @card_expire = nil unless instance_variable_defined?(:@card_expire)
          @card_expire
        end

        #
        # ===カード有効期限を設定する
        # - クレジットカードの有効期限を指定します。
        # - MM/YY （月 + "/" + 年）の形式
        # - 例） "11/09"
        # @param:: card_expire カード有効期限
        #
        def card_expire=(card_expire)
          @card_expire = card_expire
        end

        #
        # ===カード保有者名を取得する
        # @return:: カード保有者名
        #
        def cardholder_name
          @cardholder_name = nil unless instance_variable_defined?(:@cardholder_name)
          @cardholder_name
        end

        #
        # ===カード保有者名を設定する
        # - クレジットカードに印字されている保有者名を指定します。
        # @param:: cardholder_name カード保有者名
        #
        def cardholder_name=(cardholder_name)
          @cardholder_name = cardholder_name
        end

        #
        # ===カードオプションタイプを取得する
        # @return:: カードオプションタイプ
        #
        def card_option_type
          @card_option_type = nil unless instance_variable_defined?(:@card_option_type)
          @card_option_type
        end

        #
        # ===カードオプションタイプを設定する
        # - カードオプションタイプを指定します。
        # - "mpi"：
        # - "house"：
        # - "elio"： 指定できません
        # - ※ 指定が無い場合は、デフォルトのカードオプション
        # - カード番号(No3)が設定されていない場合は、元取引のカードオプションタイプとなります。
        # - カードオプション毎の必須項目については
        # - 「（別紙）パラメータ組み合わせ」を参照ください。
        # @param:: card_option_type カードオプションタイプ
        #
        def card_option_type=(card_option_type)
          @card_option_type = card_option_type
        end

        #
        # ===カード接続センターを取得する
        # @return:: カード接続センター
        #
        def card_center
          @card_center = nil unless instance_variable_defined?(:@card_center)
          @card_center
        end

        #
        # ===カード接続センターを設定する
        # - カード接続センターを指定します。（任意指定）
        # - "sln"： Sln接続"
        # - "jcn""： Jcn接続
        # - ※ 指定が無い場合は、デフォルトの接続センターを検証
        # @param:: card_center カード接続センター
        #
        def card_center=(card_center)
          @card_center = card_center
        end

        #
        # ===仕向け先コードを取得する
        # @return:: 仕向け先コード
        #
        def acquirer_code
          @acquirer_code = nil unless instance_variable_defined?(:@acquirer_code)
          @acquirer_code
        end

        #
        # ===仕向け先コードを設定する
        # - 仕向け先カード会社コードを指定します。
        # - （店舗が加盟店契約をしているカード会社）
        # - ※ 最終的に決済を行うカード発行会社ではなく、決済要求電文が最初に仕向けられる加盟店管理会社となります。
        # - 01 シティカードジャパン株式会社（ダイナースカード）
        # - 02 株式会社 ジェーシービー
        # - 03 三菱UFJニコス株式会社（旧DCカード）
        # - 04 三井住友カード株式会社（りそなカード株式会社などVISAジャパングループ）
        # - 05 三菱UFJニコス株式会社（旧UFJカード）
        # - 06 ユーシーカード株式会社
        # - 07 アメリカン・エキスプレス・インターナショナル
        # - 08 株式会社 ジャックス
        # - 09 三菱UFJニコス株式会社（旧日本信販）
        # - 10 株式会社 オリエントコーポレーション
        # - 11 株式会社 セントラルファイナンス
        # - 12 株式会社 アプラス
        # - 13 株式会社 ライフ
        # - 14 楽天KC株式会社
        # - 17 三菱UFJニコス株式会社（旧協同クレジット）
        # - 20 GEコンシューマー・ファイナンス株式会社（ジーシーカード）
        # - 21 株式会社 クレディセゾン
        # - 22 ポケットカード 株式会社
        # - 23 株式会社オーエムシーカード
        # - 24 イオンクレジットサービス株式会社
        # - 28 株式会社 バンクカードサービス
        # - 31 トヨタファイナンス 株式会社
        # - 32 株式会社 JALカード
        # - 36 株式会社クオーク
        # - 37 GEコンシューマー・ファイナンス株式会社（GEカード）
        # - 38 東急カード株式会社（TOPカード）
        # - 40 （株）UCS
        # - 47 （株）ほくせん
        # - 48 （株）ソニーファイナンスインターナショナル
        # - 49 ヤフー（株）
        # - 50 （株）ゆめカード
        # - 51 （株）オークス
        # - 52 東日本旅客鉄道（株）（ビューカード）
        # @param:: acquirer_code 仕向け先コード
        #
        def acquirer_code=(acquirer_code)
          @acquirer_code = acquirer_code
        end

        #
        # ===JPOを取得する
        # @return:: JPO
        #
        def jpo
          @jpo = nil unless instance_variable_defined?(:@jpo)
          @jpo
        end

        #
        # ===JPOを設定する
        # - JPOを指定します。（任意指定）
        # @param:: jpo JPO
        #
        def jpo=(jpo)
          @jpo = jpo
        end

        #
        # ===売上フラグを取得する
        # @return:: 売上フラグ
        #
        def with_capture
          @with_capture = nil unless instance_variable_defined?(:@with_capture)
          @with_capture
        end

        #
        # ===売上フラグを設定する
        # - 売上フラグを指定します。（任意指定）
        # - "true"： 与信・売上
        # - "false"： 与信のみ
        # - ※ 指定が無い場合は、false
        # @param:: with_capture 売上フラグ
        #
        def with_capture=(with_capture)
          @with_capture = with_capture
        end

        #
        # ===売上日を取得する
        # @return:: 売上日
        #
        def sales_day
          @sales_day = nil unless instance_variable_defined?(:@sales_day)
          @sales_day
        end

        #
        # ===売上日を設定する
        # - 売上日を指定します。（任意指定）
        # - YYYYMMDD の形式
        # - 例） "20090905"
        # - 売上フラグ（No.11)がfalseの場合は利用できません。
        # @param:: sales_day 売上日
        #
        def sales_day=(sales_day)
          @sales_day = sales_day
        end

        #
        # ===商品コードを取得する
        # @return:: 商品コード
        #
        def item_code
          @item_code = nil unless instance_variable_defined?(:@item_code)
          @item_code
        end

        #
        # ===商品コードを設定する
        # - 商品コードを指定します。（任意指定）
        # - ※ 指定が無い場合は、デフォルトの商品コード
        # @param:: item_code 商品コード
        #
        def item_code=(item_code)
          @item_code = item_code
        end

        #
        # ===3Dメッセージバージョンを取得する
        # @return:: 3Dメッセージバージョン
        #
        def ddd_message_version
          @ddd_message_version = nil unless instance_variable_defined?(:@ddd_message_version)
          @ddd_message_version
        end

        #
        # ===3Dメッセージバージョンを設定する
        # - Message Version Numberを指定します。
        # - 例） “1.0.2”
        # @param:: ddd_message_version 3Dメッセージバージョン
        #
        def ddd_message_version=(ddd_message_version)
          @ddd_message_version = ddd_message_version
        end

        #
        # ===3DトランザクションIdを取得する
        # @return:: 3DトランザクションId
        #
        def ddd_transaction_id
          @ddd_transaction_id = nil unless instance_variable_defined?(:@ddd_transaction_id)
          @ddd_transaction_id
        end

        #
        # ===3DトランザクションIdを設定する
        # - Transaction Identifier(XID)を指定します。
        # - 20桁バイナリ値をBase64にて28桁英数字に変換した値を指定します。
        # @param:: ddd_transaction_id 3DトランザクションId
        #
        def ddd_transaction_id=(ddd_transaction_id)
          @ddd_transaction_id = ddd_transaction_id
        end

        #
        # ===3Dトランザクションステータスを取得する
        # @return:: 3Dトランザクションステータス
        #
        def ddd_transaction_status
          @ddd_transaction_status = nil unless instance_variable_defined?(:@ddd_transaction_status)
          @ddd_transaction_status
        end

        #
        # ===3Dトランザクションステータスを設定する
        # - 3Dセキュアトランザクションステータスを指定します。
        # - "Y"：本人認証成功
        # - "N"：本人認証失敗（イシュアまたは会員が原因）
        # - "U"：本人認証失敗（上記以外が原因）
        # - "A"：Attempt（暫定的に本人認証成功）
        # - " ": スペース
        # - ""：値なし
        # @param:: ddd_transaction_status 3Dトランザクションステータス
        #
        def ddd_transaction_status=(ddd_transaction_status)
          @ddd_transaction_status = ddd_transaction_status
        end

        #
        # ===3DCAVVアルゴリズムを取得する
        # @return:: 3DCAVVアルゴリズム
        #
        def ddd_cavv_algorithm
          @ddd_cavv_algorithm = nil unless instance_variable_defined?(:@ddd_cavv_algorithm)
          @ddd_cavv_algorithm
        end

        #
        # ===3DCAVVアルゴリズムを設定する
        # - 3DセキュアCAVVアルゴリズムを指定します。
        # - "0"：HMAC
        # - "1"：CVV
        # - "2"：CVV with ATN
        # - "3"：SPA Algorithm
        # - " ":スペース
        # - ""：値なし
        # @param:: ddd_cavv_algorithm 3DCAVVアルゴリズム
        #
        def ddd_cavv_algorithm=(ddd_cavv_algorithm)
          @ddd_cavv_algorithm = ddd_cavv_algorithm
        end

        #
        # ===3DCAVVを取得する
        # @return:: 3DCAVV
        #
        def ddd_cavv
          @ddd_cavv = nil unless instance_variable_defined?(:@ddd_cavv)
          @ddd_cavv
        end

        #
        # ===3DCAVVを設定する
        # - 3DセキュアCAVV を指定します。
        # @param:: ddd_cavv 3DCAVV
        #
        def ddd_cavv=(ddd_cavv)
          @ddd_cavv = ddd_cavv
        end

        #
        # ===3DECIを取得する
        # @return:: 3DECI
        #
        def ddd_eci
          @ddd_eci = nil unless instance_variable_defined?(:@ddd_eci)
          @ddd_eci
        end

        #
        # ===3DECIを設定する
        # - 3Dセキュア ECI を指定します。
        # - "01"：Attempt（Master Card）
        # - "02"：認証成功（Master Card）
        # - "05"：認証成功（VISA、JCB）
        # - "06"：Attempt（VISA、JCB）または未参加（Master Card、VISA、JCB）
        # - "07"：認証実行不能（Master Card、VISA、JCB）
        # @param:: ddd_eci 3DECI
        #
        def ddd_eci=(ddd_eci)
          @ddd_eci = ddd_eci
        end

        #
        # ===3DDSトランザクションIDを取得する
        # @return:: 3DDSトランザクションID
        #
        def ddd_ds_transaction_id
          @ddd_ds_transaction_id = nil unless instance_variable_defined?(:@ddd_ds_transaction_id)
          @ddd_ds_transaction_id
        end

        #
        # ===3DDSトランザクションIDを設定する
        # - 3Dセキュア DSトランザクションID を指定します。
        # @param:: ddd_ds_transaction_id 3DDSトランザクションID
        #
        def ddd_ds_transaction_id=(ddd_ds_transaction_id)
          @ddd_ds_transaction_id = ddd_ds_transaction_id
        end

        #
        # ===3DサーバトランザクションIDを取得する
        # @return:: 3DサーバトランザクションID
        #
        def ddd_server_transaction_id
          @ddd_server_transaction_id = nil unless instance_variable_defined?(:@ddd_server_transaction_id)
          @ddd_server_transaction_id
        end

        #
        # ===3DサーバトランザクションIDを設定する
        # - 3Dセキュア サーバトランザクションID を指定します。
        # @param:: ddd_server_transaction_id 3DサーバトランザクションID
        #
        def ddd_server_transaction_id=(ddd_server_transaction_id)
          @ddd_server_transaction_id = ddd_server_transaction_id
        end

        #
        # ===セキュリティコードを取得する
        # @return:: セキュリティコード
        #
        def security_code
          @security_code = nil unless instance_variable_defined?(:@security_code)
          @security_code
        end

        #
        # ===セキュリティコードを設定する
        # - セキュリティコードを指定します。
        # @param:: security_code セキュリティコード
        #
        def security_code=(security_code)
          @security_code = security_code
        end

        #
        # ===認証コード（eLIO）を取得する
        # @return:: 認証コード（eLIO）
        #
        def auth_flag
          @auth_flag = nil unless instance_variable_defined?(:@auth_flag)
          @auth_flag
        end

        #
        # ===認証コード（eLIO）を設定する
        # - 使用できません。
        # @param:: auth_flag 認証コード（eLIO）
        #
        def auth_flag=(auth_flag)
          @auth_flag = auth_flag
        end

        #
        # ===誕生日を取得する
        # @return:: 誕生日
        #
        def birthday
          @birthday = nil unless instance_variable_defined?(:@birthday)
          @birthday
        end

        #
        # ===誕生日を設定する
        # - SLN認証アシストサービス用パラメータ[ 誕生日 ]
        # - カード利用者が入力するカード保有者の生月日(MMDD形式）を設定します。
        # - カード接続センター(No.7)がjcnと設定しているときは利用できません。
        # @param:: birthday 誕生日
        #
        def birthday=(birthday)
          @birthday = birthday
        end

        #
        # ===電話番号を取得する
        # @return:: 電話番号
        #
        def tel
          @tel = nil unless instance_variable_defined?(:@tel)
          @tel
        end

        #
        # ===電話番号を設定する
        # - SLN認証アシストサービス用パラメータ[ 電話番号 ]
        # - カード利用者が入力するカード保有者の自宅電話番号下4桁を設定します。
        # - カード接続センター(No.7)がjcnと設定しているときは利用できません。
        # @param:: tel 電話番号
        #
        def tel=(tel)
          @tel = tel
        end

        #
        # ===名前（名）カナを取得する
        # @return:: 名前（名）カナ
        #
        def first_kana_name
          @first_kana_name = nil unless instance_variable_defined?(:@first_kana_name)
          @first_kana_name
        end

        #
        # ===名前（名）カナを設定する
        # - SLN認証アシストサービス用パラメータ[ 名前（名）カナ ]
        # - カード利用者が入力するカード保有者のカナ氏名（名）を設定します。
        # - カード接続センター(No.7)がjcnと設定しているときは利用できません。
        # @param:: first_kana_name 名前（名）カナ
        #
        def first_kana_name=(first_kana_name)
          @first_kana_name = first_kana_name
        end

        #
        # ===名前（姓）カナを取得する
        # @return:: 名前（姓）カナ
        #
        def last_kana_name
          @last_kana_name = nil unless instance_variable_defined?(:@last_kana_name)
          @last_kana_name
        end

        #
        # ===名前（姓）カナを設定する
        # - SLN認証アシストサービス用パラメータ[ 名前（姓）カナ ]
        # - カード利用者が入力するカード保有者のカナ氏名（姓）を設定します。
        # - カード接続センター(No.7)がjcnと設定しているときは利用できません。
        # @param:: last_kana_name 名前（姓）カナ
        #
        def last_kana_name=(last_kana_name)
          @last_kana_name = last_kana_name
        end

        #
        # ===通貨単位を取得する
        # @return:: 通貨単位
        #
        def currency_unit
          @currency_unit = nil unless instance_variable_defined?(:@currency_unit)
          @currency_unit
        end

        #
        # ===通貨単位を設定する
        # - "jpy"のみ
        # @param:: currency_unit 通貨単位
        #
        def currency_unit=(currency_unit)
          @currency_unit = currency_unit
        end

        #
        # ===PINを取得する
        # @return:: PIN
        #
        def pin
          @pin = nil unless instance_variable_defined?(:@pin)
          @pin
        end

        #
        # ===PINを設定する
        # - PINを指定します。（任意指定）
        # @param:: pin PIN
        #
        def pin=(pin)
          @pin = pin
        end

        #
        # ===初回請求年月を取得する
        # @return:: 初回請求年月
        #
        def first_payment
          @first_payment = nil unless instance_variable_defined?(:@first_payment)
          @first_payment
        end

        #
        # ===初回請求年月を設定する
        # - 初回請求年月を指定します。
        # - YYMM （年月）の形式
        # - 例） "1310"
        # @param:: first_payment 初回請求年月
        #
        def first_payment=(first_payment)
          @first_payment = first_payment
        end

        #
        # ===ボーナス初回年月を取得する
        # @return:: ボーナス初回年月
        #
        def bonus_first_payment
          @bonus_first_payment = nil unless instance_variable_defined?(:@bonus_first_payment)
          @bonus_first_payment
        end

        #
        # ===ボーナス初回年月を設定する
        # - ボーナス初回年月を指定します。
        # - YYMM （年月）の形式
        # - 例） "1312"
        # @param:: bonus_first_payment ボーナス初回年月
        #
        def bonus_first_payment=(bonus_first_payment)
          @bonus_first_payment = bonus_first_payment
        end

        #
        # ===決済金額（多通貨）を取得する
        # @return:: 決済金額（多通貨）
        #
        def mc_amount
          @mc_amount = nil unless instance_variable_defined?(:@mc_amount)
          @mc_amount
        end

        #
        # ===決済金額（多通貨）を設定する
        # - 決済金額（多通貨）を指定します。
        # - 0 より大きくかつ 99999999 以下である必要があります。
        # @param:: mc_amount 決済金額（多通貨）
        #
        def mc_amount=(mc_amount)
          @mc_amount = mc_amount
        end

        #
        # ===POSデータコードを取得する
        # @return:: POSデータコード
        #
        def pos_data_code
          @pos_data_code = nil unless instance_variable_defined?(:@pos_data_code)
          @pos_data_code
        end

        #
        # ===POSデータコードを設定する
        # - POSデータコードを指定します。
        # @param:: pos_data_code POSデータコード
        #
        def pos_data_code=(pos_data_code)
          @pos_data_code = pos_data_code
        end

        #
        # ===端末識別番号を取得する
        # @return:: 端末識別番号
        #
        def terminal_id
          @terminal_id = nil unless instance_variable_defined?(:@terminal_id)
          @terminal_id
        end

        #
        # ===端末識別番号を設定する
        # - 端末識別番号を指定します。
        # @param:: terminal_id 端末識別番号
        #
        def terminal_id=(terminal_id)
          @terminal_id = terminal_id
        end

        #
        # ===不正検知評価取引情報を取得する
        # @return:: 不正検知評価取引情報
        #
        def fraud_detection_request
          @fraud_detection_request = nil unless instance_variable_defined?(:@fraud_detection_request)
          @fraud_detection_request
        end

        #
        # ===不正検知評価取引情報を設定する
        # - 不正検知評価取引情報を指定します。
        # @param:: fraud_detection_request 不正検知評価取引情報
        #
        def fraud_detection_request=(fraud_detection_request)
          @fraud_detection_request = fraud_detection_request
        end

        #
        # ===不正検知V2評価取引情報を取得する
        # @return:: 不正検知V2評価取引情報
        #
        def fraud_detection_v2_request
          @fraud_detection_v2_request = nil unless instance_variable_defined?(:@fraud_detection_v2_request)
          @fraud_detection_v2_request
        end

        #
        # ===不正検知V2評価取引情報を設定する
        # - 不正検知V2評価取引情報を指定します。
        # @param:: fraud_detection_v2_request 不正検知V2評価取引情報
        #
        def fraud_detection_v2_request=(fraud_detection_v2_request)
          @fraud_detection_v2_request = fraud_detection_v2_request
        end

        #
        # ===不正検知実施フラグを取得する
        # @return:: 不正検知実施フラグ
        #
        def with_fraud_detection
          @with_fraud_detection = nil unless instance_variable_defined?(:@with_fraud_detection)
          @with_fraud_detection
        end

        #
        # ===不正検知実施フラグを設定する
        # - 不正検知実施フラグを指定します。（任意指定）
        # - "true"： 実施する
        # - "false"： 実施しない
        # @param:: with_fraud_detection 不正検知実施フラグ
        #
        def with_fraud_detection=(with_fraud_detection)
          @with_fraud_detection = with_fraud_detection
        end

        #
        # ===拡張伝票情報を取得する
        # @return:: 拡張伝票情報
        #
        def ex_slip_info
          @ex_slip_info = nil unless instance_variable_defined?(:@ex_slip_info)
          @ex_slip_info
        end

        #
        # ===拡張伝票情報を設定する
        # - 半角英数字
        # - 25桁
        # - 拡張伝票情報を指定します。（任意指定）
        #
        # @param:: ex_slip_info 拡張伝票情報
        #
        def ex_slip_info=(ex_slip_info)
          @ex_slip_info = ex_slip_info
        end

        #
        # ===拡張パラメータリストを取得する
        # @return:: 拡張パラメータリスト
        #
        def option_params
          @option_params = nil unless instance_variable_defined?(:@option_params)
          @option_params
        end

        #
        # ===拡張パラメータリストを設定する
        # @param:: option_params 拡張パラメータリスト
        #
        def option_params=(option_params)
          @option_params = option_params
        end

      end
    end
  end
end
