# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/abstract_payment_request_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：キャリア、コマンド名：与信の要求Dtoクラス
      #
      # @author:: VeriTrans Inc.
      #
      class CarrierAuthorizeRequestDto < Veritrans::Tercerog::Mdk::AbstractPaymentRequestDto

        #
        # ===コンストラクタ
        #
        def initialize
          @service_type = SERVICE_TYPE
          @service_command = SERVICE_COMMAND
        end


        #
        # 決済サービスタイプ
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_TYPE = "carrier"

        #
        # 決済サービスコマンド
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_COMMAND = "Authorize"


        #
        # ===決済サービスタイプを取得する
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスコマンドを取得する
        # @return:: 決済サービスコマンド
        #
        def service_command
          @service_command = nil unless instance_variable_defined?(:@service_command)
          @service_command
        end

        #
        # ===取引IDを取得する
        # @return:: 取引ID
        #
        def order_id
          @order_id = nil unless instance_variable_defined?(:@order_id)
          @order_id
        end

        #
        # ===取引IDを設定する
        # - マーチャント側で取引を一意に表す注文管理IDを指定します。
        # - 申込処理ごとに一意である必要があります。
        # - 半角英数字、“-”（ハイフン）、“_”（アンダースコア）も使用可能です。
        # @param:: order_id 取引ID
        #
        def order_id=(order_id)
          @order_id = order_id
        end

        #
        # ===サービスオプションタイプを取得する
        # @return:: サービスオプションタイプ
        #
        def service_option_type
          @service_option_type = nil unless instance_variable_defined?(:@service_option_type)
          @service_option_type
        end

        #
        # ===サービスオプションタイプを設定する
        # - "docomo":ドコモケータイ払い
        # - "au":auかんたん決済
        # - "sb_ktai":ソフトバンクまとめて支払い（B）
        # - "sb_matomete":ソフトバンクまとめて支払い（A）
        # - "s_bikkuri":S!まとめて支払い
        # - "flets":フレッツまとめて支払い
        # @param:: service_option_type サービスオプションタイプ
        #
        def service_option_type=(service_option_type)
          @service_option_type = service_option_type
        end

        #
        # ===決済金額を取得する
        # @return:: 決済金額
        #
        def amount
          @amount = nil unless instance_variable_defined?(:@amount)
          @amount
        end

        #
        # ===決済金額を設定する
        # 決済金額を指定します。
        # - 1 以上かつ 999999999999 以下
        # 
        # @param:: amount 決済金額
        #
        def amount=(amount)
          @amount = amount
        end

        #
        # ===端末種別を取得する
        # @return:: 端末種別
        #
        def terminal_kind
          @terminal_kind = nil unless instance_variable_defined?(:@terminal_kind)
          @terminal_kind
        end

        #
        # ===端末種別を設定する
        # - 0:PC
        # - 1:スマートフォン
        # - 2:フィーチャーフォン
        # 
        # @param:: terminal_kind 端末種別
        #
        def terminal_kind=(terminal_kind)
          @terminal_kind = terminal_kind
        end

        #
        # ===商品タイプを取得する
        # @return:: 商品タイプ
        #
        def item_type
          @item_type = nil unless instance_variable_defined?(:@item_type)
          @item_type
        end

        #
        # ===商品タイプを設定する
        # - 0:デジタルコンテンツ
        # - 1:物販
        # - 2:役務
        # ※ 未指定の場合は、マーチャント登録時にDBに設定された値を使用します。
        # @param:: item_type 商品タイプ
        #
        def item_type=(item_type)
          @item_type = item_type
        end

        #
        # ===課金種別を取得する
        # @return:: 課金種別
        #
        def accounting_type
          @accounting_type = nil unless instance_variable_defined?(:@accounting_type)
          @accounting_type
        end

        #
        # ===課金種別を設定する
        # - 0:都度
        # - 1:継続
        # - 2:バーコード
        # - 3:スキャンコード
        # - 4:随時
        # @param:: accounting_type 課金種別
        #
        def accounting_type=(accounting_type)
          @accounting_type = accounting_type
        end

        #
        # ===与信同時売上フラグを取得する
        # @return:: 与信同時売上フラグ
        #
        def with_capture
          @with_capture = nil unless instance_variable_defined?(:@with_capture)
          @with_capture
        end

        #
        # ===与信同時売上フラグを設定する
        # - true : 与信同時売上
        # - false: 与信のみ
        # ※ 都度決済で未指定の場合は、false:与信のみ。ただし、sb_matometeはtrue:与信同時売上として扱います。
        # ※ 以下の場合はtrue:与信同時売上のみ。未指定の場合はtrue:与信同時売上として扱います。
        #  ・docomo(バーコード)
        #  ・au(バーコード)
        #  ・au(スキャンコード)
        # 
        # @param:: with_capture 与信同時売上フラグ
        #
        def with_capture=(with_capture)
          @with_capture = with_capture
        end

        #
        # ===本人認証（３Ｄセキュア）を取得する
        # @return:: 本人認証（３Ｄセキュア）
        #
        def d3_flag
          @d3_flag = nil unless instance_variable_defined?(:@d3_flag)
          @d3_flag
        end

        #
        # ===本人認証（３Ｄセキュア）を設定する
        # sb_ktai以外は指定できません。
        # - 0:3D無
        # - 1:3Dバイパス
        # - 2:3D有
        # ※ 未指定の場合は、「1: バイパス」
        # @param:: d3_flag 本人認証（３Ｄセキュア）
        #
        def d3_flag=(d3_flag)
          @d3_flag = d3_flag
        end

        #
        # ===初回課金年月日を取得する
        # @return:: 初回課金年月日
        #
        def mp_first_date
          @mp_first_date = nil unless instance_variable_defined?(:@mp_first_date)
          @mp_first_date
        end

        #
        # ===初回課金年月日を設定する
        # - 継続課金の場合に指定可
        # - 初回に課金される日付をYYYYMMDDの形式で指定してください。
        # - fletsの場合、日付は25日以下しか指定できません。
        # @param:: mp_first_date 初回課金年月日
        #
        def mp_first_date=(mp_first_date)
          @mp_first_date = mp_first_date
        end

        #
        # ===継続課金日を取得する
        # @return:: 継続課金日
        #
        def mp_day
          @mp_day = nil unless instance_variable_defined?(:@mp_day)
          @mp_day
        end

        #
        # ===継続課金日を設定する
        # - 継続課金の場合に指定可
        # - 初回課金年月日の翌月以降の毎月課金日を1～28で指定してください。
        # - 月末を指定する場合は99を指定してください。
        # - fletsの場合、25以下しか指定できません。
        # @param:: mp_day 継続課金日
        #
        def mp_day=(mp_day)
          @mp_day = mp_day
        end

        #
        # ===商品番号を取得する
        # @return:: 商品番号
        #
        def item_id
          @item_id = nil unless instance_variable_defined?(:@item_id)
          @item_id
        end

        #
        # ===商品番号を設定する
        # マーチャントシステム内で商品やサービスを特定するID
        # - sb_matometeの継続課金の場合は、サービス識別子を18桁以内で指定してください。
        # - fletsの場合、　8桁以下の半角数字を指定できます。
        # - その他の場合、15桁以内で任意の値を指定できます。
        # @param:: item_id 商品番号
        #
        def item_id=(item_id)
          @item_id = item_id
        end

        #
        # ===商品情報を取得する
        # @return:: 商品情報
        #
        def item_info
          @item_info = nil unless instance_variable_defined?(:@item_info)
          @item_info
        end

        #
        # ===商品情報を設定する
        # キャリアによって用途が異なる項目です。※機種依存文字は利用できません。 
        # 
        # ・docomo:
        # - キャリアが提供する消費者向けコンテンツに表示される商品情報を指定して下さい。
        # - 決済時の内容確認画面
        # - ご利用明細画面（詳細内容など）
        # - 購入完了通知メール（レシートメール）
        # ・sb_ktai:
        # - 直接契約の場合のみ、決済画面などの購入内容
        # ・sb_matomete:
        # - 購入完了通知メール本文の購入内容
        # ・flets:
        # - 決済時の内容確認画面の商品名
        # ・au:
        # - 決済時のご利用内容確認画面
        # 
        # ※au（課金種別がバーコードの場合）、sb_ktai（マーチャントの契約タイプが包括契約の場合）、s_bikkuriは指定できません。
        # 
        # ※auの都度課金の場合は24文字以下の全角文字、継続課金の場合は15文字以下の全角文字を指定できます。
        # ※その他の場合は20文字以下の全角文字を指定できます。
        # @param:: item_info 商品情報
        #
        def item_info=(item_info)
          @item_info = item_info
        end

        #
        # ===決済完了時URLを取得する
        # @return:: 決済完了時URL
        #
        def success_url
          @success_url = nil unless instance_variable_defined?(:@success_url)
          @success_url
        end

        #
        # ===決済完了時URLを設定する
        # 決済完了後に、店舗側サイトに画面遷移を戻すためのURLを指定します。
        # 
        # ※ 未指定の場合は、マーチャント登録時に設定した値を使用
        # @param:: success_url 決済完了時URL
        #
        def success_url=(success_url)
          @success_url = success_url
        end

        #
        # ===決済キャンセル時URLを取得する
        # @return:: 決済キャンセル時URL
        #
        def cancel_url
          @cancel_url = nil unless instance_variable_defined?(:@cancel_url)
          @cancel_url
        end

        #
        # ===決済キャンセル時URLを設定する
        # 決済キャンセル時に、店舗側サイトに画面遷移を戻すためのURLを指定します。
        # 
        # ※ 未指定の場合は、マーチャント登録時に設定した値を使用
        # @param:: cancel_url 決済キャンセル時URL
        #
        def cancel_url=(cancel_url)
          @cancel_url = cancel_url
        end

        #
        # ===決済エラー時URLを取得する
        # @return:: 決済エラー時URL
        #
        def error_url
          @error_url = nil unless instance_variable_defined?(:@error_url)
          @error_url
        end

        #
        # ===決済エラー時URLを設定する
        # 決済キャンセルエラー時に、店舗側サイトに画面遷移を戻すためのURLを指定します。
        # 
        # ※ 未指定の場合は、マーチャント登録時に設定した値を使用
        # @param:: error_url 決済エラー時URL
        #
        def error_url=(error_url)
          @error_url = error_url
        end

        #
        # ===プッシュ先URLを取得する
        # @return:: プッシュ先URL
        #
        def push_url
          @push_url = nil unless instance_variable_defined?(:@push_url)
          @push_url
        end

        #
        # ===プッシュ先URLを設定する
        # プッシュURLを指定します。
        # 
        # ※ ダミー取引と都度決済および随時決済の本番取引で指定可能です。
        # ※ 未指定の場合は、マーチャント登録時に設定した値を使用
        # @param:: push_url プッシュ先URL
        #
        def push_url=(push_url)
          @push_url = push_url
        end

        #
        # ===OpenIDを取得する
        # @return:: OpenID
        #
        def open_id
          @open_id = nil unless instance_variable_defined?(:@open_id)
          @open_id
        end

        #
        # ===OpenIDを設定する
        # キャリアより発行された消費者を識別するOpenIDを指定します。
        # OpenIDは、決済申込完了通知によりVeriTrans4Gから店舗側システムに連携されます。
        # 
        # sb_ktai、sb_matomete、s_bikkuri、fletsは指定できません。
        # @param:: open_id OpenID
        #
        def open_id=(open_id)
          @open_id = open_id
        end

        #
        # ===UIDを取得する
        # @return:: UID
        #
        def sb_uid
          @sb_uid = nil unless instance_variable_defined?(:@sb_uid)
          @sb_uid
        end

        #
        # ===UIDを設定する
        # 消費者端末からマーチャントシステムにアクセスした際のUIDを指定します。
        # 
        # s_bikkuriでのみ指定可能です。
        # @param:: sb_uid UID
        #
        def sb_uid=(sb_uid)
          @sb_uid = sb_uid
        end

        #
        # ===フレッツエリアを取得する
        # @return:: フレッツエリア
        #
        def flets_area
          @flets_area = nil unless instance_variable_defined?(:@flets_area)
          @flets_area
        end

        #
        # ===フレッツエリアを設定する
        # - 0:東日本
        # - 1:西日本
        # 
        # fletsでのみ指定可能です。
        # @param:: flets_area フレッツエリア
        #
        def flets_area=(flets_area)
          @flets_area = flets_area
        end

        #
        # ===auIDログインフラグを取得する
        # @return:: auIDログインフラグ
        #
        def login_au_id
          @login_au_id = nil unless instance_variable_defined?(:@login_au_id)
          @login_au_id
        end

        #
        # ===auIDログインフラグを設定する
        # - true : auIDログイン
        # - false: ID連携
        # 
        # auでのみ指定可能です。
        # @param:: login_au_id auIDログインフラグ
        #
        def login_au_id=(login_au_id)
          @login_au_id = login_au_id
        end

        #
        # ===au IDを取得する
        # @return:: au ID
        #
        def au_id
          @au_id = nil unless instance_variable_defined?(:@au_id)
          @au_id
        end

        #
        # ===au IDを設定する
        # 消費者が所有するau IDを指定します。
        # 
        # OpenIDもしくはau IDのいずれかのみ指定可能です。
        # auでのみ指定可能です。
        # loginAuIdの値に関係なく指定可能です。
        # @param:: au_id au ID
        #
        def au_id=(au_id)
          @au_id = au_id
        end

        #
        # ===決済認証方式を取得する
        # @return:: 決済認証方式
        #
        def payment_authentication_type
          @payment_authentication_type = nil unless instance_variable_defined?(:@payment_authentication_type)
          @payment_authentication_type
        end

        #
        # ===決済認証方式を設定する
        # アプリ決済認証方式フラグ
        # 
        # - 0：ID認証方式
        # - 1：アプリ方式
        # 
        # auの都度決済でのみ指定可能です。
        # ※未指定の場合は、「0：ID認証方式」
        # @param:: payment_authentication_type 決済認証方式
        #
        def payment_authentication_type=(payment_authentication_type)
          @payment_authentication_type = payment_authentication_type
        end

        #
        # ===課金トークンを取得する
        # @return:: 課金トークン
        #
        def billing_token
          @billing_token = nil unless instance_variable_defined?(:@billing_token)
          @billing_token
        end

        #
        # ===課金トークンを設定する
        # バーコード決済用課金トークン。
        # 
        # 消費者アプリのバーコードから読み取った値を設定してください。
        # auとdocomoのバーコード決済でのみ指定可能です。
        # @param:: billing_token 課金トークン
        #
        def billing_token=(billing_token)
          @billing_token = billing_token
        end

        #
        # ===ID認証を取得する
        # @return:: ID認証
        #
        def idauth
          @idauth = nil unless instance_variable_defined?(:@idauth)
          @idauth
        end

        #
        # ===ID認証を設定する
        # false：回線接続であれば回線による認証を行う
        # true：IDによる認証を必須とする
        # 
        # ※ 未指定の場合は、「false」
        # @param:: idauth ID認証
        #
        def idauth=(idauth)
          @idauth = idauth
        end

        #
        # ===店舗IDを取得する
        # @return:: 店舗ID
        #
        def store_id
          @store_id = nil unless instance_variable_defined?(:@store_id)
          @store_id
        end

        #
        # ===店舗IDを設定する
        # 以下の場合に指定可能です。
        # - au：バーコード決済、都度決済(アプリ方式)
        # - docomo：バーコード決済
        # ※auの場合は半角数字8桁以内
        # ※未指定の場合は、マーチャント登録時にDBに設定された値
        # @param:: store_id 店舗ID
        #
        def store_id=(store_id)
          @store_id = store_id
        end

        #
        # ===端末管理番号を取得する
        # @return:: 端末管理番号
        #
        def term_id
          @term_id = nil unless instance_variable_defined?(:@term_id)
          @term_id
        end

        #
        # ===端末管理番号を設定する
        # auの都度決済（アプリ方式）とバーコード決済でのみ指定可能です。
        # @param:: term_id 端末管理番号
        #
        def term_id=(term_id)
          @term_id = term_id
        end

        #
        # ===レシート番号を取得する
        # @return:: レシート番号
        #
        def receipt_no
          @receipt_no = nil unless instance_variable_defined?(:@receipt_no)
          @receipt_no
        end

        #
        # ===レシート番号を設定する
        # auのバーコード決済でのみ指定可能です。
        # @param:: receipt_no レシート番号
        #
        def receipt_no=(receipt_no)
          @receipt_no = receipt_no
        end


      end
    end
  end
end
