# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/abstract_payment_request_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：キャリア、コマンド名：取消の要求Dtoクラス
      #
      # @author:: VeriTrans Inc.
      #
      class CarrierCancelRequestDto < Veritrans::Tercerog::Mdk::AbstractPaymentRequestDto

        #
        # ===コンストラクタ
        #
        def initialize
          @service_type = SERVICE_TYPE
          @service_command = SERVICE_COMMAND
        end


        #
        # 決済サービスタイプ
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_TYPE = "carrier"

        #
        # 決済サービスコマンド
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_COMMAND = "Cancel"


        #
        # ===決済サービスタイプを取得する
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスコマンドを取得する
        # @return:: 決済サービスコマンド
        #
        def service_command
          @service_command = nil unless instance_variable_defined?(:@service_command)
          @service_command
        end

        #
        # ===取引IDを取得する
        # @return:: 取引ID
        #
        def order_id
          @order_id = nil unless instance_variable_defined?(:@order_id)
          @order_id
        end

        #
        # ===取引IDを設定する
        # キャンセル対象の取引IDを指定する。
        # @param:: order_id 取引ID
        #
        def order_id=(order_id)
          @order_id = order_id
        end

        #
        # ===サービスオプションタイプを取得する
        # @return:: サービスオプションタイプ
        #
        def service_option_type
          @service_option_type = nil unless instance_variable_defined?(:@service_option_type)
          @service_option_type
        end

        #
        # ===サービスオプションタイプを設定する
        # - "docomo":ドコモケータイ払い
        # - "au":auかんたん決済
        # - "sb_ktai":ソフトバンクまとめて支払い（B）
        # - "flets":フレッツまとめて支払い
        # 以下は指定できない。
        # - "sb_matomete":ソフトバンクまとめて支払い（A）
        # - "s_bikkuri":S!まとめて支払い
        # @param:: service_option_type サービスオプションタイプ
        #
        def service_option_type=(service_option_type)
          @service_option_type = service_option_type
        end

        #
        # ===課金取消月を取得する
        # @return:: 課金取消月
        #
        def cancel_month
          @cancel_month = nil unless instance_variable_defined?(:@cancel_month)
          @cancel_month
        end

        #
        # ===課金取消月を設定する
        # docomo, au, flets, sb_ktaiで、継続課金（月額）の取消時のみ指定可能。
        # - YYYYMM形式
        # @param:: cancel_month 課金取消月
        #
        def cancel_month=(cancel_month)
          @cancel_month = cancel_month
        end

        #
        # ===返金金額を取得する
        # @return:: 返金金額
        #
        def amount
          @amount = nil unless instance_variable_defined?(:@amount)
          @amount
        end

        #
        # ===返金金額を設定する
        # 返金する金額を指定します。
        # 例）250円*4個=1000円の買い物をし1個返品した場合には、返金金額に250円を指定します。
        # - 1 以上かつ 999999999999 以下
        # 
        # @param:: amount 返金金額
        #
        def amount=(amount)
          @amount = amount
        end

        #
        # ===店舗IDを取得する
        # @return:: 店舗ID
        #
        def store_id
          @store_id = nil unless instance_variable_defined?(:@store_id)
          @store_id
        end

        #
        # ===店舗IDを設定する
        # auのバーコード決済、スキャンコード決済で指定可能です。
        # 
        # ※未指定の場合は、Authorize時と同じ値
        # @param:: store_id 店舗ID
        #
        def store_id=(store_id)
          @store_id = store_id
        end

        #
        # ===端末管理番号を取得する
        # @return:: 端末管理番号
        #
        def term_id
          @term_id = nil unless instance_variable_defined?(:@term_id)
          @term_id
        end

        #
        # ===端末管理番号を設定する
        # auのバーコード決済、スキャンコード決済で指定可能です。
        # 
        # ※未指定の場合は、Authorize時と同じ値
        # @param:: term_id 端末管理番号
        #
        def term_id=(term_id)
          @term_id = term_id
        end

        #
        # ===レシート番号を取得する
        # @return:: レシート番号
        #
        def receipt_no
          @receipt_no = nil unless instance_variable_defined?(:@receipt_no)
          @receipt_no
        end

        #
        # ===レシート番号を設定する
        # auのバーコード決済、スキャンコード決済で指定可能です。
        # 
        # ※未指定の場合は、Authorize時と同じ値
        # @param:: receipt_no レシート番号
        #
        def receipt_no=(receipt_no)
          @receipt_no = receipt_no
        end


      end
    end
  end
end
