# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/abstract_payment_request_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：キャリア、コマンド名：再与信の要求Dtoクラス
      #
      # @author:: VeriTrans Inc.
      #
      class CarrierReAuthorizeRequestDto < Veritrans::Tercerog::Mdk::AbstractPaymentRequestDto

        #
        # ===コンストラクタ
        #
        def initialize
          @service_type = SERVICE_TYPE
          @service_command = SERVICE_COMMAND
        end


        #
        # 決済サービスタイプ
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_TYPE = "carrier"

        #
        # 決済サービスコマンド
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_COMMAND = "ReAuthorize"


        #
        # ===決済サービスタイプを取得する
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスコマンドを取得する
        # @return:: 決済サービスコマンド
        #
        def service_command
          @service_command = nil unless instance_variable_defined?(:@service_command)
          @service_command
        end

        #
        # ===取引IDを取得する
        # @return:: 取引ID
        #
        def order_id
          @order_id = nil unless instance_variable_defined?(:@order_id)
          @order_id
        end

        #
        # ===取引IDを設定する
        # - マーチャント側で取引を一意に表す注文管理IDを指定します。
        # - 申込処理ごとに一意である必要があります。
        # - 半角英数字、“-”（ハイフン）、“_”（アンダースコア）も使用可能です。
        # @param:: order_id 取引ID
        #
        def order_id=(order_id)
          @order_id = order_id
        end

        #
        # ===元取引IDを取得する
        # @return:: 元取引ID
        #
        def original_order_id
          @original_order_id = nil unless instance_variable_defined?(:@original_order_id)
          @original_order_id
        end

        #
        # ===元取引IDを設定する
        # - 随時決済承諾要求(Authorize)で指定した取引IDを指定します。
        # @param:: original_order_id 元取引ID
        #
        def original_order_id=(original_order_id)
          @original_order_id = original_order_id
        end

        #
        # ===サービスオプションタイプを取得する
        # @return:: サービスオプションタイプ
        #
        def service_option_type
          @service_option_type = nil unless instance_variable_defined?(:@service_option_type)
          @service_option_type
        end

        #
        # ===サービスオプションタイプを設定する
        # - "docomo":ドコモケータイ払い
        # - "au":auかんたん決済
        # - "sb_ktai":ソフトバンクまとめて支払い（B）
        # - "sb_matomete":ソフトバンクまとめて支払い（A）
        # - "flets":フレッツまとめて支払い
        # @param:: service_option_type サービスオプションタイプ
        #
        def service_option_type=(service_option_type)
          @service_option_type = service_option_type
        end

        #
        # ===与信同時売上フラグを取得する
        # @return:: 与信同時売上フラグ
        #
        def with_capture
          @with_capture = nil unless instance_variable_defined?(:@with_capture)
          @with_capture
        end

        #
        # ===与信同時売上フラグを設定する
        # - true : 与信同時売上
        # - false: 与信のみ
        # ※ 未指定の場合はfalseとして扱います。
        # @param:: with_capture 与信同時売上フラグ
        #
        def with_capture=(with_capture)
          @with_capture = with_capture
        end

        #
        # ===決済金額を取得する
        # @return:: 決済金額
        #
        def amount
          @amount = nil unless instance_variable_defined?(:@amount)
          @amount
        end

        #
        # ===決済金額を設定する
        # 決済金額を指定します。
        # - 1 以上かつ 999999999999 以下
        # 
        # @param:: amount 決済金額
        #
        def amount=(amount)
          @amount = amount
        end


      end
    end
  end
end
