# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/abstract_payment_request_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：キャリア、コマンド名：継続終了の要求Dtoクラス
      #
      # @author:: VeriTrans Inc.
      #
      class CarrierTerminateRequestDto < Veritrans::Tercerog::Mdk::AbstractPaymentRequestDto

        #
        # ===コンストラクタ
        #
        def initialize
          @service_type = SERVICE_TYPE
          @service_command = SERVICE_COMMAND
        end


        #
        # 決済サービスタイプ
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_TYPE = "carrier"

        #
        # 決済サービスコマンド
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_COMMAND = "Terminate"


        #
        # ===決済サービスタイプを取得する
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスコマンドを取得する
        # @return:: 決済サービスコマンド
        #
        def service_command
          @service_command = nil unless instance_variable_defined?(:@service_command)
          @service_command
        end

        #
        # ===取引IDを取得する
        # @return:: 取引ID
        #
        def order_id
          @order_id = nil unless instance_variable_defined?(:@order_id)
          @order_id
        end

        #
        # ===取引IDを設定する
        # - 継続課金を終了する対象の取引IDを指定する。
        # - 随時決済を終了する利用承諾の取引IDを指定する。
        # @param:: order_id 取引ID
        #
        def order_id=(order_id)
          @order_id = order_id
        end

        #
        # ===サービスオプションタイプを取得する
        # @return:: サービスオプションタイプ
        #
        def service_option_type
          @service_option_type = nil unless instance_variable_defined?(:@service_option_type)
          @service_option_type
        end

        #
        # ===サービスオプションタイプを設定する
        # - "docomo":ドコモケータイ払い
        # - "au":auかんたん決済
        # - "sb_matomete":ソフトバンクまとめて支払い（A）
        # - "flets":フレッツまとめて支払い
        # - "sb_ktai":ソフトバンクまとめて支払い（B）
        # 以下は指定できない。
        # - "s_bikkuri":S!まとめて支払い
        # @param:: service_option_type サービスオプションタイプ
        #
        def service_option_type=(service_option_type)
          @service_option_type = service_option_type
        end

        #
        # ===端末種別を取得する
        # @return:: 端末種別
        #
        def terminal_kind
          @terminal_kind = nil unless instance_variable_defined?(:@terminal_kind)
          @terminal_kind
        end

        #
        # ===端末種別を設定する
        # 消費者が使用している端末の種別を指定します。
        # - 0:PC
        # - 1:スマートフォン
        # - 2:フィーチャーフォン
        # ※消費者を介する終了要求（3者間）の場合に指定可能なパラメータです。
        # @param:: terminal_kind 端末種別
        #
        def terminal_kind=(terminal_kind)
          @terminal_kind = terminal_kind
        end

        #
        # ===強制終了を取得する
        # @return:: 強制終了
        #
        def force
          @force = nil unless instance_variable_defined?(:@force)
          @force
        end

        #
        # ===強制終了を設定する
        # ※docomo、sb_matomete のみ指定可能なパラメータです。
        # 
        # 継続課金の終了方式（3者間または2者間）を指定します。
        # - "true" ：強制終了（2者間）
        # - "false" ：消費者を介する終了要求（3者間／デフォルト）
        # 
        # ※auの場合は強制終了で固定のため、指定できません。
        # @param:: force 強制終了
        #
        def force=(force)
          @force = force
        end

        #
        # ===継続課金終了完了時URLを取得する
        # @return:: 継続課金終了完了時URL
        #
        def success_url
          @success_url = nil unless instance_variable_defined?(:@success_url)
          @success_url
        end

        #
        # ===継続課金終了完了時URLを設定する
        # ※消費者を介する終了要求（3者間）の場合に指定可能なパラメータです。
        # ※未指定の場合は、Authorize時に指定された値、またはマーチャント登録時に設定した値を使用
        # 
        # 継続課金終了完了後に、店舗側サイトに画面遷移を戻すためのURLを指定します。
        # @param:: success_url 継続課金終了完了時URL
        #
        def success_url=(success_url)
          @success_url = success_url
        end

        #
        # ===継続課金終了キャンセル時URLを取得する
        # @return:: 継続課金終了キャンセル時URL
        #
        def cancel_url
          @cancel_url = nil unless instance_variable_defined?(:@cancel_url)
          @cancel_url
        end

        #
        # ===継続課金終了キャンセル時URLを設定する
        # ※消費者を介する終了要求（3者間）の場合に指定可能なパラメータです。
        # ※未指定の場合は、Authorize時に指定された値、またはマーチャント登録時に設定した値を使用
        # 
        # 継続課金終了キャンセル後に、店舗側サイトに画面遷移を戻すためのURLを指定します。
        # @param:: cancel_url 継続課金終了キャンセル時URL
        #
        def cancel_url=(cancel_url)
          @cancel_url = cancel_url
        end

        #
        # ===継続課金終了エラー時URLを取得する
        # @return:: 継続課金終了エラー時URL
        #
        def error_url
          @error_url = nil unless instance_variable_defined?(:@error_url)
          @error_url
        end

        #
        # ===継続課金終了エラー時URLを設定する
        # ※消費者を介する終了要求（3者間）の場合に指定可能なパラメータです。
        # ※未指定の場合は、Authorize時に指定された値、またはマーチャント登録時に設定した値を使用
        # 
        # 継続課金終了エラー時に、店舗側サイトに画面遷移を戻すためのURLを指定します。
        # @param:: error_url 継続課金終了エラー時URL
        #
        def error_url=(error_url)
          @error_url = error_url
        end

        #
        # ===プッシュ先URLを取得する
        # @return:: プッシュ先URL
        #
        def push_url
          @push_url = nil unless instance_variable_defined?(:@push_url)
          @push_url
        end

        #
        # ===プッシュ先URLを設定する
        # 「ダミー取引」時のプッシュURLを指定します。
        # 
        # ※消費者を介する終了要求（3者間）の場合に指定可能なパラメータです。
        # ※本パラメータは店舗側システムの開発時にのみ利用されることを想定しており、ダミー取引で指定可能です。
        # ※未指定の場合は、Authorize時に指定された値、またはマーチャント登録時にDBに設定された値を使用
        # @param:: push_url プッシュ先URL
        #
        def push_url=(push_url)
          @push_url = push_url
        end


      end
    end
  end
end
