# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/abstract_payment_request_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：エポス、コマンド名：決済申込の要求Dtoクラス
      #
      # @author:: VeriTrans Inc.
      #
      class EposAuthorizeRequestDto < Veritrans::Tercerog::Mdk::AbstractPaymentRequestDto

        #
        # ===コンストラクタ
        #
        def initialize
          @service_type = SERVICE_TYPE
          @service_command = SERVICE_COMMAND
        end


        #
        # 決済サービスタイプ
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_TYPE = "epos"

        #
        # 決済サービスコマンド
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_COMMAND = "Authorize"


        #
        # ===決済サービスタイプを取得する
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスコマンドを取得する
        # @return:: 決済サービスコマンド
        #
        def service_command
          @service_command = nil unless instance_variable_defined?(:@service_command)
          @service_command
        end

        #
        # ===取引IDを取得する
        # @return:: 取引ID
        #
        def order_id
          @order_id = nil unless instance_variable_defined?(:@order_id)
          @order_id
        end

        #
        # ===取引IDを設定する
        # - マーチャント側で取引を一意に表す注文管理IDを指定します。
        # - 申込処理ごとに一意である必要があります。
        # - 半角英数字、“-”（ハイフン）、“_”（アンダースコア）も使用可能です。
        # @param:: order_id 取引ID
        #
        def order_id=(order_id)
          @order_id = order_id
        end

        #
        # ===決済金額を取得する
        # @return:: 決済金額
        #
        def amount
          @amount = nil unless instance_variable_defined?(:@amount)
          @amount
        end

        #
        # ===決済金額を設定する
        # 決済金額を指定します。
        # - 1 以上かつ 99999999(8桁) 以下
        # @param:: amount 決済金額
        #
        def amount=(amount)
          @amount = amount
        end

        #
        # ===加盟店顧客IDを取得する
        # @return:: 加盟店顧客ID
        #
        def customer_id
          @customer_id = nil unless instance_variable_defined?(:@customer_id)
          @customer_id
        end

        #
        # ===加盟店顧客IDを設定する
        # マーチャントにて顧客を一意に識別するIDを指定します。
        # @param:: customer_id 加盟店顧客ID
        #
        def customer_id=(customer_id)
          @customer_id = customer_id
        end

        #
        # ===与信同時売上フラグを取得する
        # @return:: 与信同時売上フラグ
        #
        def with_capture
          @with_capture = nil unless instance_variable_defined?(:@with_capture)
          @with_capture
        end

        #
        # ===与信同時売上フラグを設定する
        # - true : 与信同時売上
        # - false : 与信のみ 
        # ※未指定の場合は、false。
        # @param:: with_capture 与信同時売上フラグ
        #
        def with_capture=(with_capture)
          @with_capture = with_capture
        end

        #
        # ===決済完了時URLを取得する
        # @return:: 決済完了時URL
        #
        def success_url
          @success_url = nil unless instance_variable_defined?(:@success_url)
          @success_url
        end

        #
        # ===決済完了時URLを設定する
        # 決済完了後に、店舗側サイトに画面遷移を戻すためのURLを指定します。
        # - 半角256文字以内
        # 
        # ※ 未指定の場合は、マーチャント登録時に設定した値を使用
        # @param:: success_url 決済完了時URL
        #
        def success_url=(success_url)
          @success_url = success_url
        end

        #
        # ===決済キャンセル時URLを取得する
        # @return:: 決済キャンセル時URL
        #
        def cancel_url
          @cancel_url = nil unless instance_variable_defined?(:@cancel_url)
          @cancel_url
        end

        #
        # ===決済キャンセル時URLを設定する
        # 決済キャンセル時に、店舗側サイトに画面遷移を戻すためのURLを指定します。
        # - 半角256文字以内
        # 
        # ※ 未指定の場合は、マーチャント登録時に設定した値を使用
        # @param:: cancel_url 決済キャンセル時URL
        #
        def cancel_url=(cancel_url)
          @cancel_url = cancel_url
        end

        #
        # ===決済エラー時URLを取得する
        # @return:: 決済エラー時URL
        #
        def error_url
          @error_url = nil unless instance_variable_defined?(:@error_url)
          @error_url
        end

        #
        # ===決済エラー時URLを設定する
        # 決済エラー時に、店舗側サイトに画面遷移を戻すためのURLを指定します。
        # - 半角256文字以内
        # 
        # ※ 未指定の場合は、マーチャント登録時に設定した値を使用
        # @param:: error_url 決済エラー時URL
        #
        def error_url=(error_url)
          @error_url = error_url
        end

        #
        # ===プッシュ先URLを取得する
        # @return:: プッシュ先URL
        #
        def push_url
          @push_url = nil unless instance_variable_defined?(:@push_url)
          @push_url
        end

        #
        # ===プッシュ先URLを設定する
        # 「ダミー取引」時のプッシュURLを指定します。
        # - 半角256文字以内
        # 
        # ※ 未指定の場合は、マーチャント登録時に設定した値を使用
        # @param:: push_url プッシュ先URL
        #
        def push_url=(push_url)
          @push_url = push_url
        end


      end
    end
  end
end
