# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/abstract_payment_request_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：LINEPay、コマンド名：与信の要求Dtoクラス
      #
      # @author:: VeriTrans Inc.
      #
      class LinepayAuthorizeRequestDto < Veritrans::Tercerog::Mdk::AbstractPaymentRequestDto

        #
        # ===コンストラクタ
        #
        def initialize
          @service_type = SERVICE_TYPE
          @service_command = SERVICE_COMMAND
        end


        #
        # 決済サービスタイプ
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_TYPE = "linepay"

        #
        # 決済サービスコマンド
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_COMMAND = "Authorize"


        #
        # ===決済サービスタイプを取得する
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスコマンドを取得する
        # @return:: 決済サービスコマンド
        #
        def service_command
          @service_command = nil unless instance_variable_defined?(:@service_command)
          @service_command
        end

        #
        # ===取引IDを取得する
        # @return:: 取引ID
        #
        def order_id
          @order_id = nil unless instance_variable_defined?(:@order_id)
          @order_id
        end

        #
        # ===取引IDを設定する
        # - マーチャント側で取引を一意に表す注文管理IDを指定します。
        # - 申込処理ごとに一意である必要があります。
        # - 半角英数字、“-”（ハイフン）、“_”（アンダースコア）も使用可能です。
        # @param:: order_id 取引ID
        #
        def order_id=(order_id)
          @order_id = order_id
        end

        #
        # ===決済金額を取得する
        # @return:: 決済金額
        #
        def amount
          @amount = nil unless instance_variable_defined?(:@amount)
          @amount
        end

        #
        # ===決済金額を設定する
        # 決済金額を指定します。
        # - 1 以上かつ 9999999(7桁) 以下
        # @param:: amount 決済金額
        #
        def amount=(amount)
          @amount = amount
        end

        #
        # ===与信同時売上フラグを取得する
        # @return:: 与信同時売上フラグ
        #
        def with_capture
          @with_capture = nil unless instance_variable_defined?(:@with_capture)
          @with_capture
        end

        #
        # ===与信同時売上フラグを設定する
        # - true : 与信同時売上
        # - false: 与信のみ
        # ※ 未指定の場合は、false:与信のみ。
        # @param:: with_capture 与信同時売上フラグ
        #
        def with_capture=(with_capture)
          @with_capture = with_capture
        end

        #
        # ===商品番号を取得する
        # @return:: 商品番号
        #
        def item_id
          @item_id = nil unless instance_variable_defined?(:@item_id)
          @item_id
        end

        #
        # ===商品番号を設定する
        # マーチャントシステム内で商品やサービスを特定するID
        # @param:: item_id 商品番号
        #
        def item_id=(item_id)
          @item_id = item_id
        end

        #
        # ===商品名を取得する
        # @return:: 商品名
        #
        def item_name
          @item_name = nil unless instance_variable_defined?(:@item_name)
          @item_name
        end

        #
        # ===商品名を設定する
        # 商品名
        # - 最大文字数：4000byte
        # @param:: item_name 商品名
        #
        def item_name=(item_name)
          @item_name = item_name
        end

        #
        # ===商品画像URLを取得する
        # @return:: 商品画像URL
        #
        def item_image_url
          @item_image_url = nil unless instance_variable_defined?(:@item_image_url)
          @item_image_url
        end

        #
        # ===商品画像URLを設定する
        # 商品画像URL（決済画面に表示される画像URL。サイズ：84×84）
        # - 半角256byte以内
        # @param:: item_image_url 商品画像URL
        #
        def item_image_url=(item_image_url)
          @item_image_url = item_image_url
        end

        #
        # ===使用ブラウザ判定を取得する
        # @return:: 使用ブラウザ判定
        #
        def check_use_browser
          @check_use_browser = nil unless instance_variable_defined?(:@check_use_browser)
          @check_use_browser
        end

        #
        # ===使用ブラウザ判定を設定する
        # - true : 決済を要請したbrowserとLINEアプリから遷移するbrowserが異なる場合、LINE Payで決済を要請したbrowserに戻るよう案内ページを提供する。
        # - false: LINE Payで決済を要請したbrowserとLINEアプリから遷移するbrowserの確認をしない
        # ※ 未指定の場合は、false。
        # @param:: check_use_browser 使用ブラウザ判定
        #
        def check_use_browser=(check_use_browser)
          @check_use_browser = check_use_browser
        end

        #
        # ===アプリ起動URLスキームを取得する
        # @return:: アプリ起動URLスキーム
        #
        def app_url_scheme
          @app_url_scheme = nil unless instance_variable_defined?(:@app_url_scheme)
          @app_url_scheme
        end

        #
        # ===アプリ起動URLスキームを設定する
        # LINE Pay アプリが起動するブラウザまたは独自アプリケーシ
        # ョンを起動するためのURL スキーム。
        # ※決済確認方法が"サーバ間通信"の場合には指定できません。
        # @param:: app_url_scheme アプリ起動URLスキーム
        #
        def app_url_scheme=(app_url_scheme)
          @app_url_scheme = app_url_scheme
        end

        #
        # ===独自アプリ起動時のオプション指定を取得する
        # @return:: 独自アプリ起動時のオプション指定
        #
        def use_original_app
          @use_original_app = nil unless instance_variable_defined?(:@use_original_app)
          @use_original_app
        end

        #
        # ===独自アプリ起動時のオプション指定を設定する
        # - 0 : 独自アプリ起動オプションを使用しない
        # - 1 : URLエンコーディングを使用する場合に指定
        # ※ 未指定の場合は、'0'：オプションを使用しない。
        # ※決済確認方法が"サーバ間通信"の場合には指定できません。
        # @param:: use_original_app 独自アプリ起動時のオプション指定
        #
        def use_original_app=(use_original_app)
          @use_original_app = use_original_app
        end

        #
        # ===LINE member IDを取得する
        # @return:: LINE member ID
        #
        def mid
          @mid = nil unless instance_variable_defined?(:@mid)
          @mid
        end

        #
        # ===LINE member IDを設定する
        # 店舗側システムにて、LINEユーザを特定できる固有IDです。
        # - 半角50文字以内
        # 
        # 加盟店様でLINEユーザの情報にアクセスできる場合にmidを指定してください。
        # 
        # @param:: mid LINE member ID
        #
        def mid=(mid)
          @mid = mid
        end

        #
        # ===packageNameを取得する
        # @return:: packageName
        #
        def package_name
          @package_name = nil unless instance_variable_defined?(:@package_name)
          @package_name
        end

        #
        # ===packageNameを設定する
        # Androidにおいて、アプリ間切り替えの際にphishing防止用の情報
        # ※決済確認方法が"サーバ間通信"の場合には指定できません。
        # @param:: package_name packageName
        #
        def package_name=(package_name)
          @package_name = package_name
        end

        #
        # ===言語コードを取得する
        # @return:: 言語コード
        #
        def lang_cd
          @lang_cd = nil unless instance_variable_defined?(:@lang_cd)
          @lang_cd
        end

        #
        # ===言語コードを設定する
        # 決済待ち画面の言語コード（BCP-47形式）
        # - ja : 日本語
        # - ko : 韓国語
        # - en : 英語
        # - zh-Hans : 中国語（簡体字）
        # - zh-Hant : 中国語（繁体字）
        # - th : タイ語
        # ※未指定の場合は、ja:日本語
        # @param:: lang_cd 言語コード
        #
        def lang_cd=(lang_cd)
          @lang_cd = lang_cd
        end

        #
        # ===決済完了時URLを取得する
        # @return:: 決済完了時URL
        #
        def success_url
          @success_url = nil unless instance_variable_defined?(:@success_url)
          @success_url
        end

        #
        # ===決済完了時URLを設定する
        # 決済完了後に、店舗側サイトに画面遷移を戻すためのURLを指定します。
        # - 半角256文字以内
        # 
        # ※決済確認方法が"サーバ間通信"の場合には指定できません。
        # ※ 未指定の場合は、マーチャント登録時に設定した値を使用
        # @param:: success_url 決済完了時URL
        #
        def success_url=(success_url)
          @success_url = success_url
        end

        #
        # ===決済キャンセル時URLを取得する
        # @return:: 決済キャンセル時URL
        #
        def cancel_url
          @cancel_url = nil unless instance_variable_defined?(:@cancel_url)
          @cancel_url
        end

        #
        # ===決済キャンセル時URLを設定する
        # 決済キャンセル時に、店舗側サイトに画面遷移を戻すためのURLを指定します。
        # - 半角256文字以内
        # 
        # ※決済確認方法が"サーバ間通信"の場合には指定できません。
        # ※ 未指定の場合は、マーチャント登録時に設定した値を使用
        # @param:: cancel_url 決済キャンセル時URL
        #
        def cancel_url=(cancel_url)
          @cancel_url = cancel_url
        end

        #
        # ===決済エラー時URLを取得する
        # @return:: 決済エラー時URL
        #
        def error_url
          @error_url = nil unless instance_variable_defined?(:@error_url)
          @error_url
        end

        #
        # ===決済エラー時URLを設定する
        # 決済エラー時に、店舗側サイトに画面遷移を戻すためのURLを指定します。
        # - 半角256文字以内
        # 
        # ※決済確認方法が"サーバ間通信"の場合には指定できません。
        # ※ 未指定の場合は、マーチャント登録時に設定した値を使用
        # @param:: error_url 決済エラー時URL
        #
        def error_url=(error_url)
          @error_url = error_url
        end

        #
        # ===プッシュ先URLを取得する
        # @return:: プッシュ先URL
        #
        def push_url
          @push_url = nil unless instance_variable_defined?(:@push_url)
          @push_url
        end

        #
        # ===プッシュ先URLを設定する
        # 「ダミー取引」時のプッシュURLを指定します。
        # - 半角256文字以内
        # 
        # ※ 本パラメータは店舗側システムの開発時にのみ利用されることを想定しており、ダミー取引で指定可能です。
        # @param:: push_url プッシュ先URL
        #
        def push_url=(push_url)
          @push_url = push_url
        end

        #
        # ===ワンタイムキーを取得する
        # @return:: ワンタイムキー
        #
        def one_time_key
          @one_time_key = nil unless instance_variable_defined?(:@one_time_key)
          @one_time_key
        end

        #
        # ===ワンタイムキーを設定する
        # 店舗レジ等でQRコードもしくはバーコード読み取りによる決済を実行する場合に使用します。
        # LINE Pay アプリで提供するQR/BarCodeから取得できるコード値を指定してください。
        # ※ワンタイムキー指定時には、決済確認方法に「1 : サーバ間通信」を設定してください。
        # @param:: one_time_key ワンタイムキー
        #
        def one_time_key=(one_time_key)
          @one_time_key = one_time_key
        end

        #
        # ===決済確認方法を取得する
        # @return:: 決済確認方法
        #
        def payment_confirm_type
          @payment_confirm_type = nil unless instance_variable_defined?(:@payment_confirm_type)
          @payment_confirm_type
        end

        #
        # ===決済確認方法を設定する
        # 決済確認の方式を指定します。
        # - 0 : ブラウザを介する通信（デフォルト）
        # - 1 : サーバ間通信
        # @param:: payment_confirm_type 決済確認方法
        #
        def payment_confirm_type=(payment_confirm_type)
          @payment_confirm_type = payment_confirm_type
        end


      end
    end
  end
end
