# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/response_base_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：MasterPass、コマンド名：与信の応答Dtoクラス
      #
      # @author:: VeriTrans Inc.
      #
      class MasterpassAuthorizeResponseDto < Veritrans::Tercerog::Mdk::ResponseBaseDto

        #
        # ===決済サービスタイプを取得する
        # 決済サービスの区分が固定値として指定されます。
        # "masterpass"： MasterPass
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスタイプを設定する
        # @param:: service_type 決済サービスタイプ
        #
        def service_type=(service_type)
          @service_type = service_type
        end

        #
        # ===処理結果コードを取得する
        # 決済請求処理後、応答電文に含まれる値。
        # 以下の処理結果のいずれかが格納される
        # - success：正常終了
        # - failure：異常終了
        # - pending：保留状態
        # @return:: 処理結果コード
        #
        def mstatus
          @mstatus = nil unless instance_variable_defined?(:@mstatus)
          @mstatus
        end

        #
        # ===処理結果コードを設定する
        # @param:: mstatus 処理結果コード
        #
        def mstatus=(mstatus)
          @mstatus = mstatus
        end

        #
        # ===詳細結果コードを取得する
        # 処理結果を詳細に表すコードを返却します。
        # 
        # 4桁ずつ4つのブロックで構成され、各ブロックでサービス毎の処理結果を表します。
        # @return:: 詳細結果コード
        #
        def v_result_code
          @v_result_code = nil unless instance_variable_defined?(:@v_result_code)
          @v_result_code
        end

        #
        # ===詳細結果コードを設定する
        # @param:: v_result_code 詳細結果コード
        #
        def v_result_code=(v_result_code)
          @v_result_code = v_result_code
        end

        #
        # ===エラーメッセージを取得する
        # 処理結果に対するメッセージを返却します。
        # @return:: エラーメッセージ
        #
        def merr_msg
          @merr_msg = nil unless instance_variable_defined?(:@merr_msg)
          @merr_msg
        end

        #
        # ===エラーメッセージを設定する
        # @param:: merr_msg エラーメッセージ
        #
        def merr_msg=(merr_msg)
          @merr_msg = merr_msg
        end

        #
        # ===電文IDを取得する
        # @return:: 電文ID
        #
        def march_txn
          @march_txn = nil unless instance_variable_defined?(:@march_txn)
          @march_txn
        end

        #
        # ===電文IDを設定する
        # @param:: march_txn 電文ID
        #
        def march_txn=(march_txn)
          @march_txn = march_txn
        end

        #
        # ===取引IDを取得する
        # @return:: 取引ID
        #
        def order_id
          @order_id = nil unless instance_variable_defined?(:@order_id)
          @order_id
        end

        #
        # ===取引IDを設定する
        # @param:: order_id 取引ID
        #
        def order_id=(order_id)
          @order_id = order_id
        end

        #
        # ===仕向け先コードを取得する
        # 店舗が加盟店契約をしているカード会社のコード
        # @return:: 仕向け先コード
        #
        def acquirer_code
          @acquirer_code = nil unless instance_variable_defined?(:@acquirer_code)
          @acquirer_code
        end

        #
        # ===仕向け先コードを設定する
        # @param:: acquirer_code 仕向け先コード
        #
        def acquirer_code=(acquirer_code)
          @acquirer_code = acquirer_code
        end

        #
        # ===承認番号を取得する
        # カード会社が発行する承認番号
        # @return:: 承認番号
        #
        def auth_code
          @auth_code = nil unless instance_variable_defined?(:@auth_code)
          @auth_code
        end

        #
        # ===承認番号を設定する
        # @param:: auth_code 承認番号
        #
        def auth_code=(auth_code)
          @auth_code = auth_code
        end

        #
        # ===取引毎に付くIDを取得する
        # @return:: 取引毎に付くID
        #
        def cust_txn
          @cust_txn = nil unless instance_variable_defined?(:@cust_txn)
          @cust_txn
        end

        #
        # ===取引毎に付くIDを設定する
        # @param:: cust_txn 取引毎に付くID
        #
        def cust_txn=(cust_txn)
          @cust_txn = cust_txn
        end

        #
        # ===取引日時（YYYYMMDDhhmmss）を取得する
        # カード決済で処理が完了した日時を返します。
        # @return:: 取引日時（YYYYMMDDhhmmss）
        #
        def authorize_datetime
          @authorize_datetime = nil unless instance_variable_defined?(:@authorize_datetime)
          @authorize_datetime
        end

        #
        # ===取引日時（YYYYMMDDhhmmss）を設定する
        # @param:: authorize_datetime 取引日時（YYYYMMDDhhmmss）
        #
        def authorize_datetime=(authorize_datetime)
          @authorize_datetime = authorize_datetime
        end

        #
        # ===カード決済取引IDを取得する
        # カード決済で処理した際の取引IDを返します。
        # @return:: カード決済取引ID
        #
        def card_order_id
          @card_order_id = nil unless instance_variable_defined?(:@card_order_id)
          @card_order_id
        end

        #
        # ===カード決済取引IDを設定する
        # @param:: card_order_id カード決済取引ID
        #
        def card_order_id=(card_order_id)
          @card_order_id = card_order_id
        end

        #
        # ===trAd広告URLを取得する
        # @return:: trAd広告URL
        #
        def trad_url
          @trad_url = nil unless instance_variable_defined?(:@trad_url)
          @trad_url
        end

        #
        # ===trAd広告URLを設定する
        # @param:: trad_url trAd広告URL
        #
        def trad_url=(trad_url)
          @trad_url = trad_url
        end

        #
        # ===MDKバージョンを取得する
        # 電文のバージョン番号を返却します。
        # @return:: MDKバージョン
        #
        def txn_version
          @txn_version = nil unless instance_variable_defined?(:@txn_version)
          @txn_version
        end

        #
        # ===MDKバージョンを設定する
        # @param:: txn_version MDKバージョン
        #
        def txn_version=(txn_version)
          @txn_version = txn_version
        end


        #
        # ===PayNowIDオブジェクトを取得する
        # @return:: PayNowIDオブジェクト
        #
        def pay_now_id_response
          @pay_now_id_response = nil unless instance_variable_defined?(:@pay_now_id_response)
          @pay_now_id_response
        end

        #
        # ===PayNowIDオブジェクトを設定する
        # @param:: pay_now_id_response PayNowIDオブジェクト
        #
        def pay_now_id_response=(pay_now_id_response)
          @pay_now_id_response = pay_now_id_response
        end

      end
    end
  end
end
