# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/abstract_payment_request_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：MasterPass、コマンド名：売上の要求Dtoクラス
      #
      # @author:: VeriTrans Inc.
      #
      class MasterpassCaptureRequestDto < Veritrans::Tercerog::Mdk::AbstractPaymentRequestDto

        #
        # ===コンストラクタ
        #
        def initialize
          @service_type = SERVICE_TYPE
          @service_command = SERVICE_COMMAND
        end


        #
        # 決済サービスタイプ
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_TYPE = "masterpass"

        #
        # 決済サービスコマンド
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_COMMAND = "Capture"


        #
        # ===決済サービスタイプを取得する
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスコマンドを取得する
        # @return:: 決済サービスコマンド
        #
        def service_command
          @service_command = nil unless instance_variable_defined?(:@service_command)
          @service_command
        end

        #
        # ===取引IDを取得する
        # @return:: 取引ID
        #
        def order_id
          @order_id = nil unless instance_variable_defined?(:@order_id)
          @order_id
        end

        #
        # ===取引IDを設定する
        # 売上を計上する対象の取引IDを指定する
        # @param:: order_id 取引ID
        #
        def order_id=(order_id)
          @order_id = order_id
        end

        #
        # ===金額を取得する
        # @return:: 金額
        #
        def amount
          @amount = nil unless instance_variable_defined?(:@amount)
          @amount
        end

        #
        # ===金額を設定する
        # 売上を計上する金額を指定します。
        # 指定なしまたは与信金額と同額指定時は通常の売上確定とし、1円以上与信額未満の場合部分売上となります。
        # @param:: amount 金額
        #
        def amount=(amount)
          @amount = amount
        end

        #
        # ===初回請求年月を取得する
        # @return:: 初回請求年月
        #
        def first_payment
          @first_payment = nil unless instance_variable_defined?(:@first_payment)
          @first_payment
        end

        #
        # ===初回請求年月を設定する
        # 与信時のJPOが31,34,61の場合に初回請求月をYYMM形式で指定します。与信時のJPOが上記以外の場合は設定されているとエラーになります。
        # 指定がない場合には初回請求年月を指定せずに売上を行います（JPOパラメータ内の数値で補完されません）。
        # 
        # @param:: first_payment 初回請求年月
        #
        def first_payment=(first_payment)
          @first_payment = first_payment
        end

        #
        # ===ボーナス初回年月を取得する
        # @return:: ボーナス初回年月
        #
        def bonus_first_payment
          @bonus_first_payment = nil unless instance_variable_defined?(:@bonus_first_payment)
          @bonus_first_payment
        end

        #
        # ===ボーナス初回年月を設定する
        # 与信時のJPOが24,34の場合にボーナス初回月をYYMM形式で指定します。与信時のJPOが上記以外の場合は設定されているとエラーになります。
        # 指定がない場合にはボーナス初回月を指定せずに売上を行います（JPOパラメータ内の数値で補完されません）。
        # 
        # @param:: bonus_first_payment ボーナス初回年月
        #
        def bonus_first_payment=(bonus_first_payment)
          @bonus_first_payment = bonus_first_payment
        end


      end
    end
  end
end
