# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/response_base_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：MPI、コマンド名：本人認証結果取得の応答Dtoクラス
      #
      # @author:: VeriTrans Inc.
      #
      class MpiGetResultResponseDto < Veritrans::Tercerog::Mdk::ResponseBaseDto

        #
        # ===決済サービスタイプを取得する
        # 決済サービスの区分を返却します。
        # - "mpi"： MPI
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスタイプを設定する
        # @param:: service_type 決済サービスタイプ
        #
        def service_type=(service_type)
          @service_type = service_type
        end

        #
        # ===処理結果コードを取得する
        # 決済請求処理後、応答電文に含まれる値。
        # 以下の処理結果のいずれかが格納される
        # - success：正常終了
        # - failure：異常終了
        # @return:: 処理結果コード
        #
        def mstatus
          @mstatus = nil unless instance_variable_defined?(:@mstatus)
          @mstatus
        end

        #
        # ===処理結果コードを設定する
        # @param:: mstatus 処理結果コード
        #
        def mstatus=(mstatus)
          @mstatus = mstatus
        end

        #
        # ===詳細結果コードを取得する
        # 処理結果を詳細に表すコードを返却します。
        # 
        # 4桁ずつ4つのブロックで構成され、各ブロックでサービス毎の処理結果を表します。
        # @return:: 詳細結果コード
        #
        def v_result_code
          @v_result_code = nil unless instance_variable_defined?(:@v_result_code)
          @v_result_code
        end

        #
        # ===詳細結果コードを設定する
        # @param:: v_result_code 詳細結果コード
        #
        def v_result_code=(v_result_code)
          @v_result_code = v_result_code
        end

        #
        # ===エラーメッセージを取得する
        # 処理結果に対するメッセージを返却します。
        # @return:: エラーメッセージ
        #
        def merr_msg
          @merr_msg = nil unless instance_variable_defined?(:@merr_msg)
          @merr_msg
        end

        #
        # ===エラーメッセージを設定する
        # @param:: merr_msg エラーメッセージ
        #
        def merr_msg=(merr_msg)
          @merr_msg = merr_msg
        end

        #
        # ===取引IDを取得する
        # @return:: 取引ID
        #
        def order_id
          @order_id = nil unless instance_variable_defined?(:@order_id)
          @order_id
        end

        #
        # ===取引IDを設定する
        # @param:: order_id 取引ID
        #
        def order_id=(order_id)
          @order_id = order_id
        end

        #
        # ===MDKバージョンを取得する
        # 電文のバージョン番号を返却します。
        # @return:: MDKバージョン
        #
        def txn_version
          @txn_version = nil unless instance_variable_defined?(:@txn_version)
          @txn_version
        end

        #
        # ===MDKバージョンを設定する
        # @param:: txn_version MDKバージョン
        #
        def txn_version=(txn_version)
          @txn_version = txn_version
        end

        #
        # ===リクエストIDを取得する
        # 本人認証の結果を検索する際のキー項目
        # @return:: リクエストID
        #
        def request_id
          @request_id = nil unless instance_variable_defined?(:@request_id)
          @request_id
        end

        #
        # ===リクエストIDを設定する
        # @param:: request_id リクエストID
        #
        def request_id=(request_id)
          @request_id = request_id
        end

        #
        # ===要求取引金額を取得する
        # 要求電文に設定した値
        # @return:: 要求取引金額
        #
        def req_amount
          @req_amount = nil unless instance_variable_defined?(:@req_amount)
          @req_amount
        end

        #
        # ===要求取引金額を設定する
        # @param:: req_amount 要求取引金額
        #
        def req_amount=(req_amount)
          @req_amount = req_amount
        end

        #
        # ===要求カード番号を取得する
        # 要求電文に設定した値
        # 上6桁下2桁のみ数字表示され、その他は"*"（アスタリスク）に変換されます。
        # @return:: 要求カード番号
        #
        def req_card_number
          @req_card_number = nil unless instance_variable_defined?(:@req_card_number)
          @req_card_number
        end

        #
        # ===要求カード番号を設定する
        # @param:: req_card_number 要求カード番号
        #
        def req_card_number=(req_card_number)
          @req_card_number = req_card_number
        end

        #
        # ===要求通貨単位を取得する
        # 要求電文に設定した値
        # @return:: 要求通貨単位
        #
        def req_currency_unit
          @req_currency_unit = nil unless instance_variable_defined?(:@req_currency_unit)
          @req_currency_unit
        end

        #
        # ===要求通貨単位を設定する
        # @param:: req_currency_unit 要求通貨単位
        #
        def req_currency_unit=(req_currency_unit)
          @req_currency_unit = req_currency_unit
        end

        #
        # ===本人認証処理結果コードを取得する
        # 本人認証の処理結果ステータス
        # "success"：正常終了
        # "failure"：異常終了
        # @return:: 本人認証処理結果コード
        #
        def mpi_mstatus
          @mpi_mstatus = nil unless instance_variable_defined?(:@mpi_mstatus)
          @mpi_mstatus
        end

        #
        # ===本人認証処理結果コードを設定する
        # @param:: mpi_mstatus 本人認証処理結果コード
        #
        def mpi_mstatus=(mpi_mstatus)
          @mpi_mstatus = mpi_mstatus
        end

        #
        # ===本人認証詳細結果コードを取得する
        # 本人認証処理の結果を詳細に表すコード
        # 4桁ずつ4つのブロックで構成され、各ブロックでサービス毎の処理結果を表します。
        # 詳細は『結果コード一覧』を参照下さい。
        # @return:: 本人認証詳細結果コード
        #
        def mpi_vresult_code
          @mpi_vresult_code = nil unless instance_variable_defined?(:@mpi_vresult_code)
          @mpi_vresult_code
        end

        #
        # ===本人認証詳細結果コードを設定する
        # @param:: mpi_vresult_code 本人認証詳細結果コード
        #
        def mpi_vresult_code=(mpi_vresult_code)
          @mpi_vresult_code = mpi_vresult_code
        end

        #
        # ===トランザクションタイプを取得する
        # 本人認証の実施方法を表す値
        # "AuthorizeConfirm"：フリクションレスフロー
        # "VerifyNotify"：チャレンジフロー
        # @return:: トランザクションタイプ
        #
        def txn_type
          @txn_type = nil unless instance_variable_defined?(:@txn_type)
          @txn_type
        end

        #
        # ===トランザクションタイプを設定する
        # @param:: txn_type トランザクションタイプ
        #
        def txn_type=(txn_type)
          @txn_type = txn_type
        end

        #
        # ===カード結果コードを取得する
        # [serviceOptionTypeが（mpi-complete / mpi-company / mpi-merchant）の場合のみ]
        # カード決済の処理結果ステータス
        # "success"：正常終了
        # "failure"：異常終了
        # "pending"：ペンディング
        # ※MPI結果コードがfailureの場合は空
        # @return:: カード結果コード
        #
        def card_mstatus
          @card_mstatus = nil unless instance_variable_defined?(:@card_mstatus)
          @card_mstatus
        end

        #
        # ===カード結果コードを設定する
        # @param:: card_mstatus カード結果コード
        #
        def card_mstatus=(card_mstatus)
          @card_mstatus = card_mstatus
        end

        #
        # ===カードトランザクションタイプを取得する
        # [serviceOptionTypeが（mpi-complete / mpi-company / mpi-merchant）の場合のみ]
        # カード決済取引の詳細な状態
        # "a"：与信
        # "ax"：与信（期限切れ）
        # "ap"：与信（保留）
        # "ac"：与信売上
        # "acp"：与信売上（保留）
        # @return:: カードトランザクションタイプ
        #
        def card_transaction_type
          @card_transaction_type = nil unless instance_variable_defined?(:@card_transaction_type)
          @card_transaction_type
        end

        #
        # ===カードトランザクションタイプを設定する
        # @param:: card_transaction_type カードトランザクションタイプ
        #
        def card_transaction_type=(card_transaction_type)
          @card_transaction_type = card_transaction_type
        end

        #
        # ===センター要求日時を取得する
        # [serviceOptionTypeが（mpi-complete / mpi-company / mpi-merchant）の場合のみ]
        # カード決済センターへ決済要求を行った日時
        # YYYYMMDDhhmmss形式
        # @return:: センター要求日時
        #
        def center_request_date
          @center_request_date = nil unless instance_variable_defined?(:@center_request_date)
          @center_request_date
        end

        #
        # ===センター要求日時を設定する
        # @param:: center_request_date センター要求日時
        #
        def center_request_date=(center_request_date)
          @center_request_date = center_request_date
        end

        #
        # ===センター応答日時を取得する
        # [serviceOptionTypeが（mpi-complete / mpi-company / mpi-merchant）の場合のみ]
        # カード決済センターの決済応答を受けた日時
        # YYYYMMDDhhmmss形式
        # @return:: センター応答日時
        #
        def center_response_date
          @center_response_date = nil unless instance_variable_defined?(:@center_response_date)
          @center_response_date
        end

        #
        # ===センター応答日時を設定する
        # @param:: center_response_date センター応答日時
        #
        def center_response_date=(center_response_date)
          @center_response_date = center_response_date
        end

        #
        # ===接続先カード接続センターを取得する
        # [serviceOptionTypeが（mpi-complete / mpi-company / mpi-merchant）の場合のみ]
        # 決済サーバー⇒カード会社間の接続センター名
        # 例：‘ｊｃｎ‘
        # @return:: 接続先カード接続センター
        #
        def connected_center_id
          @connected_center_id = nil unless instance_variable_defined?(:@connected_center_id)
          @connected_center_id
        end

        #
        # ===接続先カード接続センターを設定する
        # @param:: connected_center_id 接続先カード接続センター
        #
        def connected_center_id=(connected_center_id)
          @connected_center_id = connected_center_id
        end

        #
        # ===要求仕向け先コードを取得する
        # [serviceOptionTypeが（mpi-complete / mpi-company / mpi-merchant）の場合のみ]
        # 決済要求電文が最初に仕向けられたカード会社のコード
        # 仕向け先カード会社の一覧は『インターフェース詳細　～クレジットカード決済～』の「クレジットカード決済　　仕向け先カード会社の一覧」を参照
        # @return:: 要求仕向け先コード
        #
        def acquirer_code
          @acquirer_code = nil unless instance_variable_defined?(:@acquirer_code)
          @acquirer_code
        end

        #
        # ===要求仕向け先コードを設定する
        # @param:: acquirer_code 要求仕向け先コード
        #
        def acquirer_code=(acquirer_code)
          @acquirer_code = acquirer_code
        end

        #
        # ===応答承認番号を取得する
        # [serviceOptionTypeが（mpi-complete / mpi-company / mpi-merchant）の場合のみ]
        # カード会社が発行する承認番号
        # @return:: 応答承認番号
        #
        def auth_code
          @auth_code = nil unless instance_variable_defined?(:@auth_code)
          @auth_code
        end

        #
        # ===応答承認番号を設定する
        # @param:: auth_code 応答承認番号
        #
        def auth_code=(auth_code)
          @auth_code = auth_code
        end

        #
        # ===不正検知結果コードを取得する
        # [不正検知実施 かつ serviceOptionTypeが（mpi-complete / mpi-company / mpi-merchant）の場合のみ]
        # 不正検知結果
        # "100"：accept
        # "200"：deny
        # "300"：challenge
        # "400"：error
        # "500"：timeout
        # "600"：internal error
        # ""：値なし（空白）
        # @return:: 不正検知結果コード
        #
        def fd_result
          @fd_result = nil unless instance_variable_defined?(:@fd_result)
          @fd_result
        end

        #
        # ===不正検知結果コードを設定する
        # @param:: fd_result 不正検知結果コード
        #
        def fd_result=(fd_result)
          @fd_result = fd_result
        end

        #
        # ===trAd URLを取得する
        # [serviceOptionTypeが（mpi-complete / mpi-company / mpi-merchant）の場合のみ]
        # trAd URL
        # @return:: trAd URL
        #
        def trad_url
          @trad_url = nil unless instance_variable_defined?(:@trad_url)
          @trad_url
        end

        #
        # ===trAd URLを設定する
        # @param:: trad_url trAd URL
        #
        def trad_url=(trad_url)
          @trad_url = trad_url
        end

        #
        # ===3Dメッセージバージョンを取得する
        # [serviceOptionTypeが（mpi-none）の場合のみ]
        # Message Version Number
        # （例 “1.0.2”）
        # @return:: 3Dメッセージバージョン
        #
        def ddd_message_version
          @ddd_message_version = nil unless instance_variable_defined?(:@ddd_message_version)
          @ddd_message_version
        end

        #
        # ===3Dメッセージバージョンを設定する
        # @param:: ddd_message_version 3Dメッセージバージョン
        #
        def ddd_message_version=(ddd_message_version)
          @ddd_message_version = ddd_message_version
        end

        #
        # ===3DトランザクションIDを取得する
        # [serviceOptionTypeが（mpi-none）の場合のみ]
        # Transaction Identifier(XID)の値をBase64で変換した値
        # ※値が返戻された場合はカード与信電文に本項目を設定してください。
        # @return:: 3DトランザクションID
        #
        def ddd_transaction_id
          @ddd_transaction_id = nil unless instance_variable_defined?(:@ddd_transaction_id)
          @ddd_transaction_id
        end

        #
        # ===3DトランザクションIDを設定する
        # @param:: ddd_transaction_id 3DトランザクションID
        #
        def ddd_transaction_id=(ddd_transaction_id)
          @ddd_transaction_id = ddd_transaction_id
        end

        #
        # ===3DDSトランザクションIDを取得する
        # [3Dセキュア 2.0 かつ serviceOptionTypeが（mpi-none）の場合のみ]
        # Directory server transaction ID（ディレクトリサーバトランザクションID）
        # ※UUIDのフォーマットまたはBASE64エンコードされた値が返戻されます。
        # @return:: 3DDSトランザクションID
        #
        def ddd_ds_transaction_id
          @ddd_ds_transaction_id = nil unless instance_variable_defined?(:@ddd_ds_transaction_id)
          @ddd_ds_transaction_id
        end

        #
        # ===3DDSトランザクションIDを設定する
        # @param:: ddd_ds_transaction_id 3DDSトランザクションID
        #
        def ddd_ds_transaction_id=(ddd_ds_transaction_id)
          @ddd_ds_transaction_id = ddd_ds_transaction_id
        end

        #
        # ===3DサーバトランザクションIDを取得する
        # [3Dセキュア 2.0 かつ serviceOptionTypeが（mpi-none）の場合のみ]
        # 3DSサーバによって割り当てられたユニークなトランザクション識別子
        # ※UUIDのフォーマットで返戻されます。
        # @return:: 3DサーバトランザクションID
        #
        def ddd_server_transaction_id
          @ddd_server_transaction_id = nil unless instance_variable_defined?(:@ddd_server_transaction_id)
          @ddd_server_transaction_id
        end

        #
        # ===3DサーバトランザクションIDを設定する
        # @param:: ddd_server_transaction_id 3DサーバトランザクションID
        #
        def ddd_server_transaction_id=(ddd_server_transaction_id)
          @ddd_server_transaction_id = ddd_server_transaction_id
        end

        #
        # ===3Dトランザクションステータスを取得する
        # [serviceOptionTypeが（mpi-none）の場合のみ]
        # 3Dセキュアトランザクションステータス
        # "Y"：本人認証成功
        # "N"：本人認証失敗（イシュアまたは会員が原因）
        # "U"：本人認証失敗（上記以外が原因）
        # "A"：Attempt（暫定的に本人認証成功）
        # "R"：本人認証拒否
        # ""：値なし（空白）
        # @return:: 3Dトランザクションステータス
        #
        def ddd_transaction_status
          @ddd_transaction_status = nil unless instance_variable_defined?(:@ddd_transaction_status)
          @ddd_transaction_status
        end

        #
        # ===3Dトランザクションステータスを設定する
        # @param:: ddd_transaction_status 3Dトランザクションステータス
        #
        def ddd_transaction_status=(ddd_transaction_status)
          @ddd_transaction_status = ddd_transaction_status
        end

        #
        # ===3Dトランザクションステータス理由を取得する
        # [3Dセキュア 2.0 かつ serviceOptionTypeが（mpi-none）の場合のみ]
        # 3Dトランザクションステータスの値の設定理由
        # "01":Card authentication failed
        # "02":Unknown Device
        # "03":Unsupported Device
        # "04":Exceeds authentication frequency limit
        # "05":Expired card
        # "06":Invalid card number
        # "07":Invalid transaction
        # "08":No Card record
        # "09":Security failure
        # "10":Stolen card
        # "11":Suspected fraud
        # "12":Transaction not permitted to cardholder
        # "13":Cardholder not enrolled in service
        # "14":Transaction timed out at the ACS
        # "15":Low confidence
        # "16":Medium confidence
        # "17":High confidence
        # "18":Very High confidence
        # "19":Exceeds ACS maximum challenges
        # "20":Non-Payment transaction not supported
        # "21":3RI transaction not supported
        # "22":ACS technical issue
        # "23":Decoupled Authentication required by ACS but not requested by 3DS Requestor
        # "24":3DS Requestor Decoupled Max Expiry Time exceeded
        # "25":Decoupled Authentication was provided insufficient time to authenticate cardholder. ACS will not make attempt
        # "26":Authentication attempted but not performed by the cardholder
        # ""：値なし（空白）
        # ※カード会社の仕様により、上記以外の値で設定されることもあります。
        # @return:: 3Dトランザクションステータス理由
        #
        def ddd_transaction_status_reason
          @ddd_transaction_status_reason = nil unless instance_variable_defined?(:@ddd_transaction_status_reason)
          @ddd_transaction_status_reason
        end

        #
        # ===3Dトランザクションステータス理由を設定する
        # @param:: ddd_transaction_status_reason 3Dトランザクションステータス理由
        #
        def ddd_transaction_status_reason=(ddd_transaction_status_reason)
          @ddd_transaction_status_reason = ddd_transaction_status_reason
        end

        #
        # ===3DCAVVアルゴリズムを取得する
        # [serviceOptionTypeが（mpi-none）の場合のみ]
        # 3DセキュアCAVVアルゴリズム
        # "0"：HMAC
        # "1"：CVV
        # "2"：CVV with ATN
        # "3"：SPA Algorithm
        # "4"：AEVV Algorithm
        # "9"：取引毎の指定なし（3Dセキュア 2.0以上の場合）
        # ""：値なし（空白）
        # ※カード会社の仕様により、上記以外の値で設定されることもあります。
        # @return:: 3DCAVVアルゴリズム
        #
        def ddd_cavv_algorithm
          @ddd_cavv_algorithm = nil unless instance_variable_defined?(:@ddd_cavv_algorithm)
          @ddd_cavv_algorithm
        end

        #
        # ===3DCAVVアルゴリズムを設定する
        # @param:: ddd_cavv_algorithm 3DCAVVアルゴリズム
        #
        def ddd_cavv_algorithm=(ddd_cavv_algorithm)
          @ddd_cavv_algorithm = ddd_cavv_algorithm
        end

        #
        # ===3DCAVVを取得する
        # [serviceOptionTypeが（mpi-none）の場合のみ]
        # 3DセキュアCAVV
        # @return:: 3DCAVV
        #
        def ddd_cavv
          @ddd_cavv = nil unless instance_variable_defined?(:@ddd_cavv)
          @ddd_cavv
        end

        #
        # ===3DCAVVを設定する
        # @param:: ddd_cavv 3DCAVV
        #
        def ddd_cavv=(ddd_cavv)
          @ddd_cavv = ddd_cavv
        end

        #
        # ===3DECIを取得する
        # [serviceOptionTypeが（mpi-none）の場合のみ]
        # 3DセキュアECI
        # [3Dセキュア 1.0.2の場合]
        # "01"：Attempt（Master Card）
        # "02"：認証成功（Master Card）
        # "05"：認証成功（VISA、JCB）
        # "06"：Attempt（VISA、JCB）又は未参加（Master Card、VISA、JCB）
        # "07"：認証実行不能（Master Card、VISA、JCB）
        # ""：値なし（空白）
        # [3Dセキュア 2.0の場合]
        # "05"：認証成功
        # "06"：Attempt又は未参加
        # "07"：認証実行不能
        # ""：値なし（空白）
        # @return:: 3DECI
        #
        def ddd_eci
          @ddd_eci = nil unless instance_variable_defined?(:@ddd_eci)
          @ddd_eci
        end

        #
        # ===3DECIを設定する
        # @param:: ddd_eci 3DECI
        #
        def ddd_eci=(ddd_eci)
          @ddd_eci = ddd_eci
        end


        #
        # ===PayNowIDオブジェクトを取得する
        # @return:: PayNowIDオブジェクト
        #
        def pay_now_id_response
          @pay_now_id_response = nil unless instance_variable_defined?(:@pay_now_id_response)
          @pay_now_id_response
        end

        #
        # ===PayNowIDオブジェクトを設定する
        # @param:: pay_now_id_response PayNowIDオブジェクト
        #
        def pay_now_id_response=(pay_now_id_response)
          @pay_now_id_response = pay_now_id_response
        end



      end
    end
  end
end
