# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/abstract_payment_request_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：paypay、コマンド名：決済申込の要求Dtoクラス
      #
      # @author:: VeriTrans Inc.
      #
      class PaypayAuthorizeRequestDto < Veritrans::Tercerog::Mdk::AbstractPaymentRequestDto

        #
        # ===コンストラクタ
        #
        def initialize
          @service_type = SERVICE_TYPE
          @service_command = SERVICE_COMMAND
        end


        #
        # 決済サービスタイプ
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_TYPE = "paypay"

        #
        # 決済サービスコマンド
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_COMMAND = "Authorize"


        #
        # ===決済サービスタイプを取得する
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスコマンドを取得する
        # @return:: 決済サービスコマンド
        #
        def service_command
          @service_command = nil unless instance_variable_defined?(:@service_command)
          @service_command
        end

        #
        # ===取引IDを取得する
        # @return:: 取引ID
        #
        def order_id
          @order_id = nil unless instance_variable_defined?(:@order_id)
          @order_id
        end

        #
        # ===取引IDを設定する
        # - マーチャント側で取引を一意に表す注文管理IDを指定します。
        # - 申込処理ごとに一意である必要があります。
        # - 半角英数字、“-”（ハイフン）、“_”（アンダースコア）も使用可能です。
        # @param:: order_id 取引ID
        #
        def order_id=(order_id)
          @order_id = order_id
        end

        #
        # ===サービスオプションタイプを取得する
        # @return:: サービスオプションタイプ
        #
        def service_option_type
          @service_option_type = nil unless instance_variable_defined?(:@service_option_type)
          @service_option_type
        end

        #
        # ===サービスオプションタイプを設定する
        # - "barcode":バーコード決済
        # - "online":オンライン決済
        # @param:: service_option_type サービスオプションタイプ
        #
        def service_option_type=(service_option_type)
          @service_option_type = service_option_type
        end

        #
        # ===課金種別を取得する
        # @return:: 課金種別
        #
        def accounting_type
          @accounting_type = nil unless instance_variable_defined?(:@accounting_type)
          @accounting_type
        end

        #
        # ===課金種別を設定する
        # - 0:都度決済
        # - 1:随時決済
        # 
        # serviceOptionType="barcode"（バーコード決済） ： 指定できません
        # serviceOptionType="online"（オンライン決済）    ： 指定任意※
        # ※オンライン決済で未指定の場合、"0"都度決済になります。
        # @param:: accounting_type 課金種別
        #
        def accounting_type=(accounting_type)
          @accounting_type = accounting_type
        end

        #
        # ===ワンタイムコードを取得する
        # @return:: ワンタイムコード
        #
        def one_time_code
          @one_time_code = nil unless instance_variable_defined?(:@one_time_code)
          @one_time_code
        end

        #
        # ===ワンタイムコードを設定する
        # ユーザの端末から読み取ったバーコード情報を指定します。
        # 
        # serviceOptionType="barcode"（バーコード決済） ： 指定必須
        # serviceOptionType="online"（オンライン決済）    ： 指定できません
        # @param:: one_time_code ワンタイムコード
        #
        def one_time_code=(one_time_code)
          @one_time_code = one_time_code
        end

        #
        # ===決済金額を取得する
        # @return:: 決済金額
        #
        def amount
          @amount = nil unless instance_variable_defined?(:@amount)
          @amount
        end

        #
        # ===決済金額を設定する
        # 決済金額を指定します。
        # - 1 以上かつ 9999999(7桁) 以下
        # 
        # accountingType="1"（随時決済） ： 指定できません
        # @param:: amount 決済金額
        #
        def amount=(amount)
          @amount = amount
        end

        #
        # ===与信同時売上フラグを取得する
        # @return:: 与信同時売上フラグ
        #
        def with_capture
          @with_capture = nil unless instance_variable_defined?(:@with_capture)
          @with_capture
        end

        #
        # ===与信同時売上フラグを設定する
        # - true : 与信同時売上
        # 
        # serviceOptionType="barcode"（バーコード決済） ： 指定任意（※1）
        # serviceOptionType="online"（オンライン決済）    ： 指定できません（※2）
        # 
        # ※1 指定可能な値は"true"のみ。未指定の場合は、"true"を設定します。
        # ※2 指定があった場合には指定値を無視して処理します。
        # @param:: with_capture 与信同時売上フラグ
        #
        def with_capture=(with_capture)
          @with_capture = with_capture
        end

        #
        # ===店舗IDを取得する
        # @return:: 店舗ID
        #
        def store_id
          @store_id = nil unless instance_variable_defined?(:@store_id)
          @store_id
        end

        #
        # ===店舗IDを設定する
        # 店舗IDを指定します。
        # - 半角英数字、“-”（ハイフン）、“_”（アンダースコア）も使用可能です。
        # 
        # serviceOptionType="barcode"（バーコード決済） ： 指定必須
        # serviceOptionType="online"（オンライン決済）    ： 指定できません
        # @param:: store_id 店舗ID
        #
        def store_id=(store_id)
          @store_id = store_id
        end

        #
        # ===店舗端末IDを取得する
        # @return:: 店舗端末ID
        #
        def terminal_id
          @terminal_id = nil unless instance_variable_defined?(:@terminal_id)
          @terminal_id
        end

        #
        # ===店舗端末IDを設定する
        # 店舗端末IDを指定します。
        # - 半角英数字、“-”（ハイフン）、“_”（アンダースコア）も使用可能です。
        # 
        # serviceOptionType="barcode"（バーコード決済） ： 指定必須
        # serviceOptionType="online"（オンライン決済）    ： 指定できません
        # @param:: terminal_id 店舗端末ID
        #
        def terminal_id=(terminal_id)
          @terminal_id = terminal_id
        end

        #
        # ===レシート番号を取得する
        # @return:: レシート番号
        #
        def receipt_number
          @receipt_number = nil unless instance_variable_defined?(:@receipt_number)
          @receipt_number
        end

        #
        # ===レシート番号を設定する
        # レシートに印字される番号を指定します。
        # 
        # serviceOptionType="barcode"（バーコード決済） ： 指定任意
        # serviceOptionType="online"（オンライン決済）    ： 指定できません
        # @param:: receipt_number レシート番号
        #
        def receipt_number=(receipt_number)
          @receipt_number = receipt_number
        end

        #
        # ===決済事業者コードを取得する
        # @return:: 決済事業者コード
        #
        def settle_biz_code
          @settle_biz_code = nil unless instance_variable_defined?(:@settle_biz_code)
          @settle_biz_code
        end

        #
        # ===決済事業者コードを設定する
        # 決済事業者コードを指定します。
        # 
        # serviceOptionType="barcode"（バーコード決済） ： 指定任意
        # serviceOptionType="online"（オンライン決済）    ： 指定できません
        # @param:: settle_biz_code 決済事業者コード
        #
        def settle_biz_code=(settle_biz_code)
          @settle_biz_code = settle_biz_code
        end

        #
        # ===商品名を取得する
        # @return:: 商品名
        #
        def item_name
          @item_name = nil unless instance_variable_defined?(:@item_name)
          @item_name
        end

        #
        # ===商品名を設定する
        # 商品名を指定します。
        # - 最大文字数
        # 　　serviceOptionType="barcode"（バーコード決済） ： 128byte
        # 　　serviceOptionType="online"（オンライン決済）    ： 40byte
        # 
        # serviceOptionType="barcode"（バーコード決済） ： 指定必須
        # serviceOptionType="online"（オンライン決済）    ： 指定任意
        # @param:: item_name 商品名
        #
        def item_name=(item_name)
          @item_name = item_name
        end

        #
        # ===商品IDを取得する
        # @return:: 商品ID
        #
        def item_id
          @item_id = nil unless instance_variable_defined?(:@item_id)
          @item_id
        end

        #
        # ===商品IDを設定する
        # マーチャントシステム内で商品やサービスを特定するID
        # 
        # serviceOptionType="barcode"（バーコード決済） ： 指定できません
        # serviceOptionType="online"（オンライン決済）    ： 指定必須
        # @param:: item_id 商品ID
        #
        def item_id=(item_id)
          @item_id = item_id
        end

        #
        # ===決済完了時URLを取得する
        # @return:: 決済完了時URL
        #
        def success_url
          @success_url = nil unless instance_variable_defined?(:@success_url)
          @success_url
        end

        #
        # ===決済完了時URLを設定する
        # 決済完了後に、店舗側サイトに画面遷移を戻すためのURLを指定します。
        # 
        # serviceOptionType="barcode"（バーコード決済） ： 指定できません
        # serviceOptionType="online"（オンライン決済）    ： 指定任意※
        # ※未指定の場合は、MAP（Merchant Administrator Portal）から登録申請した値を使用。
        # @param:: success_url 決済完了時URL
        #
        def success_url=(success_url)
          @success_url = success_url
        end

        #
        # ===決済キャンセル時URLを取得する
        # @return:: 決済キャンセル時URL
        #
        def cancel_url
          @cancel_url = nil unless instance_variable_defined?(:@cancel_url)
          @cancel_url
        end

        #
        # ===決済キャンセル時URLを設定する
        # 決済キャンセル時に、店舗側サイトに画面遷移を戻すためのURLを指定します。
        # 
        # serviceOptionType="barcode"（バーコード決済） ： 指定できません
        # serviceOptionType="online"（オンライン決済）    ： 指定任意※
        # ※未指定の場合は、MAP（Merchant Administrator Portal）から登録申請した値を使用。
        # @param:: cancel_url 決済キャンセル時URL
        #
        def cancel_url=(cancel_url)
          @cancel_url = cancel_url
        end

        #
        # ===決済エラー時URLを取得する
        # @return:: 決済エラー時URL
        #
        def error_url
          @error_url = nil unless instance_variable_defined?(:@error_url)
          @error_url
        end

        #
        # ===決済エラー時URLを設定する
        # 決済キャンセルエラー時に、店舗側サイトに画面遷移を戻すためのURLを指定します。
        # 
        # serviceOptionType="barcode"（バーコード決済） ： 指定できません
        # serviceOptionType="online"（オンライン決済）    ： 指定任意※
        # ※未指定の場合は、MAP（Merchant Administrator Portal）から登録申請した値を使用。
        # @param:: error_url 決済エラー時URL
        #
        def error_url=(error_url)
          @error_url = error_url
        end

        #
        # ===プッシュ先URLを取得する
        # @return:: プッシュ先URL
        #
        def push_url
          @push_url = nil unless instance_variable_defined?(:@push_url)
          @push_url
        end

        #
        # ===プッシュ先URLを設定する
        # プッシュURLを指定します。
        # 
        # serviceOptionType="barcode"（バーコード決済） ： 指定できません
        # serviceOptionType="online"（オンライン決済）    ： 指定任意※
        # ※未指定の場合は、MAP（Merchant Administrator Portal）から登録申請した値を使用。
        # @param:: push_url プッシュ先URL
        #
        def push_url=(push_url)
          @push_url = push_url
        end

        #
        # ===遷移種別を取得する
        # @return:: 遷移種別
        #
        def transition_type
          @transition_type = nil unless instance_variable_defined?(:@transition_type)
          @transition_type
        end

        #
        # ===遷移種別を設定する
        # ユーザ導線における外部ブラウザの起動を回避するかどうかを指定します。
        # - 1 : アプリから遷移(WebLink)
        # - 2 : アプリから遷移(DeepLink)
        # 
        # serviceOptionType="barcode"（バーコード決済） ： 指定できません
        # serviceOptionType="online"（オンライン決済）    ： 指定任意※
        # ※accountingType="1"（随時決済） ： 指定できません
        # @param:: transition_type 遷移種別
        #
        def transition_type=(transition_type)
          @transition_type = transition_type
        end

        #
        # ===拡張パラメータフラグを取得する
        # @return:: 拡張パラメータフラグ
        #
        def extend_parameter_type
          @extend_parameter_type = nil unless instance_variable_defined?(:@extend_parameter_type)
          @extend_parameter_type
        end

        #
        # ===拡張パラメータフラグを設定する
        # 応答電文、結果通知およびリダイレクトする時のパラメータの設定タイプを指定します。
        # - 0 : デフォルトタイプの設定
        # - 1 : 拡張タイプの設定（今後パラメタが追加される可能性があります。）
        # 
        # serviceOptionType="barcode"（バーコード決済） ： 指定できません
        # serviceOptionType="online"（オンライン決済）    ： 指定任意※
        # ※未指定の場合は、MAP（Merchant Administrator Portal）から登録申請した値を使用。
        # 　登録申請した値が無い場合は、"0"を指定します。
        # @param:: extend_parameter_type 拡張パラメータフラグ
        #
        def extend_parameter_type=(extend_parameter_type)
          @extend_parameter_type = extend_parameter_type
        end


      end
    end
  end
end
