# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/abstract_payment_request_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：paypay、コマンド名：売上の要求Dtoクラス
      #
      # @author:: VeriTrans Inc.
      #
      class PaypayCaptureRequestDto < Veritrans::Tercerog::Mdk::AbstractPaymentRequestDto

        #
        # ===コンストラクタ
        #
        def initialize
          @service_type = SERVICE_TYPE
          @service_command = SERVICE_COMMAND
        end


        #
        # 決済サービスタイプ
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_TYPE = "paypay"

        #
        # 決済サービスコマンド
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_COMMAND = "Capture"


        #
        # ===決済サービスタイプを取得する
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスコマンドを取得する
        # @return:: 決済サービスコマンド
        #
        def service_command
          @service_command = nil unless instance_variable_defined?(:@service_command)
          @service_command
        end

        #
        # ===取引IDを取得する
        # @return:: 取引ID
        #
        def order_id
          @order_id = nil unless instance_variable_defined?(:@order_id)
          @order_id
        end

        #
        # ===取引IDを設定する
        # 売上対象の取引IDを指定する。
        # @param:: order_id 取引ID
        #
        def order_id=(order_id)
          @order_id = order_id
        end

        #
        # ===サービスオプションタイプを取得する
        # @return:: サービスオプションタイプ
        #
        def service_option_type
          @service_option_type = nil unless instance_variable_defined?(:@service_option_type)
          @service_option_type
        end

        #
        # ===サービスオプションタイプを設定する
        # - "online":オンライン決済
        # 
        # ※オンラン決済のみ指定可
        # @param:: service_option_type サービスオプションタイプ
        #
        def service_option_type=(service_option_type)
          @service_option_type = service_option_type
        end

        #
        # ===売上金額を取得する
        # @return:: 売上金額
        #
        def amount
          @amount = nil unless instance_variable_defined?(:@amount)
          @amount
        end

        #
        # ===売上金額を設定する
        # 売上する金額を指定します。
        # 例）250円*4個=1000円の買い物をし3個分を売上、1個取消した場合には、売上金額に750円を指定します。
        # - 1 以上かつ 9999999 以下
        # - 与信金額以下
        # 
        # serviceOptionType="online"（オンライン決済）    ： 指定任意
        # ※指定しなかった場合は、全額売上になります。
        # @param:: amount 売上金額
        #
        def amount=(amount)
          @amount = amount
        end

        #
        # ===注文の説明を取得する
        # @return:: 注文の説明
        #
        def order_description
          @order_description = nil unless instance_variable_defined?(:@order_description)
          @order_description
        end

        #
        # ===注文の説明を設定する
        # ユーザの明細に表示される注文の説明を指定します。
        # 説明は与信金額未満を指定した部分売上の場合のみユーザの明細に表示されます。
        # 全額売上の場合は指定しても説明自体が表示されません。
        # 
        # - 最大文字数
        # 　　serviceOptionType="online"（オンライン決済）    ： 255byte
        # 
        # serviceOptionType="online"（オンライン決済）    ： 指定任意
        # @param:: order_description 注文の説明
        #
        def order_description=(order_description)
          @order_description = order_description
        end


      end
    end
  end
end
