# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/abstract_payment_request_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：paypay、コマンド名：返金の要求Dtoクラス
      #
      # @author:: VeriTrans Inc.
      #
      class PaypayRefundRequestDto < Veritrans::Tercerog::Mdk::AbstractPaymentRequestDto

        #
        # ===コンストラクタ
        #
        def initialize
          @service_type = SERVICE_TYPE
          @service_command = SERVICE_COMMAND
        end


        #
        # 決済サービスタイプ
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_TYPE = "paypay"

        #
        # 決済サービスコマンド
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_COMMAND = "Refund"


        #
        # ===決済サービスタイプを取得する
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスコマンドを取得する
        # @return:: 決済サービスコマンド
        #
        def service_command
          @service_command = nil unless instance_variable_defined?(:@service_command)
          @service_command
        end

        #
        # ===取引IDを取得する
        # @return:: 取引ID
        #
        def order_id
          @order_id = nil unless instance_variable_defined?(:@order_id)
          @order_id
        end

        #
        # ===取引IDを設定する
        # 返金対象の取引IDを指定する。
        # @param:: order_id 取引ID
        #
        def order_id=(order_id)
          @order_id = order_id
        end

        #
        # ===サービスオプションタイプを取得する
        # @return:: サービスオプションタイプ
        #
        def service_option_type
          @service_option_type = nil unless instance_variable_defined?(:@service_option_type)
          @service_option_type
        end

        #
        # ===サービスオプションタイプを設定する
        # - "barcode":バーコード決済
        # - "online":オンライン決済
        # @param:: service_option_type サービスオプションタイプ
        #
        def service_option_type=(service_option_type)
          @service_option_type = service_option_type
        end

        #
        # ===店舗IDを取得する
        # @return:: 店舗ID
        #
        def store_id
          @store_id = nil unless instance_variable_defined?(:@store_id)
          @store_id
        end

        #
        # ===店舗IDを設定する
        # 店舗IDを指定します。
        # - 半角英数字、“-”（ハイフン）、“_”（アンダースコア）も使用可能です。
        # 
        # serviceOptionType="barcode"（バーコード決済） ： 指定任意
        # serviceOptionType="online"（オンライン決済）    ： 指定できません
        # @param:: store_id 店舗ID
        #
        def store_id=(store_id)
          @store_id = store_id
        end

        #
        # ===店舗端末IDを取得する
        # @return:: 店舗端末ID
        #
        def terminal_id
          @terminal_id = nil unless instance_variable_defined?(:@terminal_id)
          @terminal_id
        end

        #
        # ===店舗端末IDを設定する
        # 店舗端末IDを指定します。
        # - 半角英数字、“-”（ハイフン）、“_”（アンダースコア）も使用可能です。
        # 
        # serviceOptionType="barcode"（バーコード決済） ： 指定任意
        # serviceOptionType="online"（オンライン決済）    ： 指定できません
        # @param:: terminal_id 店舗端末ID
        #
        def terminal_id=(terminal_id)
          @terminal_id = terminal_id
        end

        #
        # ===レシート番号を取得する
        # @return:: レシート番号
        #
        def receipt_number
          @receipt_number = nil unless instance_variable_defined?(:@receipt_number)
          @receipt_number
        end

        #
        # ===レシート番号を設定する
        # レシートに印字される番号を指定します。
        # 
        # serviceOptionType="barcode"（バーコード決済） ： 指定任意
        # serviceOptionType="online"（オンライン決済）    ： 指定できません
        # @param:: receipt_number レシート番号
        #
        def receipt_number=(receipt_number)
          @receipt_number = receipt_number
        end

        #
        # ===決済事業者コードを取得する
        # @return:: 決済事業者コード
        #
        def settle_biz_code
          @settle_biz_code = nil unless instance_variable_defined?(:@settle_biz_code)
          @settle_biz_code
        end

        #
        # ===決済事業者コードを設定する
        # 決済事業者コードを指定します。
        # 
        # serviceOptionType="barcode"（バーコード決済） ： 指定任意
        # serviceOptionType="online"（オンライン決済）    ： 指定できません
        # @param:: settle_biz_code 決済事業者コード
        #
        def settle_biz_code=(settle_biz_code)
          @settle_biz_code = settle_biz_code
        end

        #
        # ===返金金額を取得する
        # @return:: 返金金額
        #
        def amount
          @amount = nil unless instance_variable_defined?(:@amount)
          @amount
        end

        #
        # ===返金金額を設定する
        # 返金する金額を指定します。
        # 例）250円*4個=1000円の買い物をし1個返品した場合には、返金金額に250円を指定します。
        # - 1 以上かつ 9999999 以下
        # 
        # serviceOptionType="barcode"（バーコード決済） ： 指定できません
        # serviceOptionType="online"（オンライン決済）    ： 指定任意
        # ※オンライン決済で指定しなかった場合は、全額返金になります。
        # @param:: amount 返金金額
        #
        def amount=(amount)
          @amount = amount
        end


      end
    end
  end
end
