# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/abstract_payment_request_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：paypay、コマンド名：解約の要求Dtoクラス
      #
      # @author:: VeriTrans Inc.
      #
      class PaypayTerminateRequestDto < Veritrans::Tercerog::Mdk::AbstractPaymentRequestDto

        #
        # ===コンストラクタ
        #
        def initialize
          @service_type = SERVICE_TYPE
          @service_command = SERVICE_COMMAND
        end


        #
        # 決済サービスタイプ
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_TYPE = "paypay"

        #
        # 決済サービスコマンド
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_COMMAND = "Terminate"


        #
        # ===決済サービスタイプを取得する
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスコマンドを取得する
        # @return:: 決済サービスコマンド
        #
        def service_command
          @service_command = nil unless instance_variable_defined?(:@service_command)
          @service_command
        end

        #
        # ===取引IDを取得する
        # @return:: 取引ID
        #
        def order_id
          @order_id = nil unless instance_variable_defined?(:@order_id)
          @order_id
        end

        #
        # ===取引IDを設定する
        # - 随時決済を解約する対象の取引IDを指定する。
        # 
        # @param:: order_id 取引ID
        #
        def order_id=(order_id)
          @order_id = order_id
        end

        #
        # ===サービスオプションタイプを取得する
        # @return:: サービスオプションタイプ
        #
        def service_option_type
          @service_option_type = nil unless instance_variable_defined?(:@service_option_type)
          @service_option_type
        end

        #
        # ===サービスオプションタイプを設定する
        # - "online":オンライン決済
        # ※オンラン決済のみ指定可
        # @param:: service_option_type サービスオプションタイプ
        #
        def service_option_type=(service_option_type)
          @service_option_type = service_option_type
        end

        #
        # ===強制解約を取得する
        # @return:: 強制解約
        #
        def force
          @force = nil unless instance_variable_defined?(:@force)
          @force
        end

        #
        # ===強制解約を設定する
        # 解約の方式（3者間または2者間）を指定します。
        # - "true" ：強制解約（2者間）
        # - "false" ：消費者を介する解約要求（3者間／デフォルト）
        # 
        # @param:: force 強制解約
        #
        def force=(force)
          @force = force
        end

        #
        # ===解約完了時URLを取得する
        # @return:: 解約完了時URL
        #
        def success_url
          @success_url = nil unless instance_variable_defined?(:@success_url)
          @success_url
        end

        #
        # ===解約完了時URLを設定する
        # 解約完了後に、店舗側サイトに画面遷移を戻すためのURLを指定します。
        # 
        # ※消費者を介する解約要求（3者間）の場合に指定可能なパラメータです。
        # ※未指定の場合は、Authorize時に指定された値、またはMAP（Merchant Administrator Portal）から登録申請した値を使用。
        # @param:: success_url 解約完了時URL
        #
        def success_url=(success_url)
          @success_url = success_url
        end

        #
        # ===解約キャンセル時URLを取得する
        # @return:: 解約キャンセル時URL
        #
        def cancel_url
          @cancel_url = nil unless instance_variable_defined?(:@cancel_url)
          @cancel_url
        end

        #
        # ===解約キャンセル時URLを設定する
        # 解約キャンセル時に、店舗側サイトに画面遷移を戻すためのURLを指定します。
        # 
        # ※消費者を介する解約要求（3者間）の場合に指定可能なパラメータです。
        # ※未指定の場合は、Authorize時に指定された値、またはMAP（Merchant Administrator Portal）から登録申請した値を使用。
        # @param:: cancel_url 解約キャンセル時URL
        #
        def cancel_url=(cancel_url)
          @cancel_url = cancel_url
        end

        #
        # ===解約エラー時URLを取得する
        # @return:: 解約エラー時URL
        #
        def error_url
          @error_url = nil unless instance_variable_defined?(:@error_url)
          @error_url
        end

        #
        # ===解約エラー時URLを設定する
        # 解約キャンセルエラー時に、店舗側サイトに画面遷移を戻すためのURLを指定します。
        # 
        # ※消費者を介する解約要求（3者間）の場合に指定可能なパラメータです。
        # ※未指定の場合は、Authorize時に指定された値、またはMAP（Merchant Administrator Portal）から登録申請した値を使用。
        # @param:: error_url 解約エラー時URL
        #
        def error_url=(error_url)
          @error_url = error_url
        end

        #
        # ===プッシュ先URLを取得する
        # @return:: プッシュ先URL
        #
        def push_url
          @push_url = nil unless instance_variable_defined?(:@push_url)
          @push_url
        end

        #
        # ===プッシュ先URLを設定する
        # プッシュURLを指定します。
        # 
        # ※消費者を介する解約要求（3者間）の場合に指定可能なパラメータです。
        # ※未指定の場合は、Authorize時に指定された値、またはMAP（Merchant Administrator Portal）から登録申請した値を使用。
        # @param:: push_url プッシュ先URL
        #
        def push_url=(push_url)
          @push_url = push_url
        end


      end
    end
  end
end
