# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/abstract_payment_request_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：楽天、コマンド名：取消の要求Dtoクラス
      #
      # @author:: VeriTrans Inc.
      #
      class RakutenCancelRequestDto < Veritrans::Tercerog::Mdk::AbstractPaymentRequestDto

        #
        # ===コンストラクタ
        #
        def initialize
          @service_type = SERVICE_TYPE
          @service_command = SERVICE_COMMAND
        end


        #
        # 決済サービスタイプ
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_TYPE = "rakuten"

        #
        # 決済サービスコマンド
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_COMMAND = "Cancel"


        #
        # ===決済サービスタイプを取得する
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスコマンドを取得する
        # @return:: 決済サービスコマンド
        #
        def service_command
          @service_command = nil unless instance_variable_defined?(:@service_command)
          @service_command
        end

        #
        # ===取引IDを取得する
        # @return:: 取引ID
        #
        def order_id
          @order_id = nil unless instance_variable_defined?(:@order_id)
          @order_id
        end

        #
        # ===取引IDを設定する
        # キャンセル対象の取引IDを指定する。
        # @param:: order_id 取引ID
        #
        def order_id=(order_id)
          @order_id = order_id
        end

        #
        # ===金額を取得する
        # @return:: 金額
        #
        def amount
          @amount = nil unless instance_variable_defined?(:@amount)
          @amount
        end

        #
        # ===金額を設定する
        # 減額する金額を指定する
        # 
        # payType=0（オンライン決済）：売上前の場合は全額以外を指定できません。売上後は指定任意
        # payType=1（バーコード決済（店舗スキャン型））、3（バーコード決済（消費者スキャン型））：指定できません
        # payType=2（オンライン決済（V2））:売上前の場合は全額以外を指定できません。売上後は指定任意。
        # @param:: amount 金額
        #
        def amount=(amount)
          @amount = amount
        end

        #
        # ===店舗IDを取得する
        # @return:: 店舗ID
        #
        def store_id
          @store_id = nil unless instance_variable_defined?(:@store_id)
          @store_id
        end

        #
        # ===店舗IDを設定する
        # 店舗番号を指定します。
        # - 半角英数字、“-”（ハイフン）、“_”（アンダースコア）も使用可能です。
        # 
        # payType=0（オンライン決済）：指定できません
        # payType=1（バーコード決済（店舗スキャン型））、3（バーコード決済（消費者スキャン型））：指定任意
        # payType=2（オンライン決済（V2））：指定できません
        # @param:: store_id 店舗ID
        #
        def store_id=(store_id)
          @store_id = store_id
        end

        #
        # ===店舗端末IDを取得する
        # @return:: 店舗端末ID
        #
        def terminal_id
          @terminal_id = nil unless instance_variable_defined?(:@terminal_id)
          @terminal_id
        end

        #
        # ===店舗端末IDを設定する
        # 端末を識別するIDを指定します。
        # - 半角英数字、“-”（ハイフン）、“_”（アンダースコア）も使用可能です。
        # 
        # payType=0（オンライン決済）：指定できません
        # payType=1（バーコード決済（店舗スキャン型））、3（バーコード決済（消費者スキャン型））：指定任意
        # payType=2（オンライン決済（V2））：指定できません
        # @param:: terminal_id 店舗端末ID
        #
        def terminal_id=(terminal_id)
          @terminal_id = terminal_id
        end

        #
        # ===キャンセル理由種別を取得する
        # @return:: キャンセル理由種別
        #
        def cancel_type
          @cancel_type = nil unless instance_variable_defined?(:@cancel_type)
          @cancel_type
        end

        #
        # ===キャンセル理由種別を設定する
        # キャンセル理由の種別を下記のコード値から指定します。
        # 
        # - 10: 重複しての決済
        # - 11: 商品の返品
        # - 12: お支払方法の変更
        # - 13: 金額の間違い
        # - 14: テスト決済
        # - 98: 障害取消（タイムアウトなど）
        # - 99: その他
        # 
        # payType=0（オンライン決済）：指定できません
        # payType=1（バーコード決済（店舗スキャン型））、3（バーコード決済（消費者スキャン型））：指定必須
        # payType=2（オンライン決済（V2））：指定できません
        # @param:: cancel_type キャンセル理由種別
        #
        def cancel_type=(cancel_type)
          @cancel_type = cancel_type
        end

        #
        # ===キャンセル理由詳細を取得する
        # @return:: キャンセル理由詳細
        #
        def cancel_reason
          @cancel_reason = nil unless instance_variable_defined?(:@cancel_reason)
          @cancel_reason
        end

        #
        # ===キャンセル理由詳細を設定する
        # キャンセル理由の詳細を記載します。
        # -最大文字数:1024byte
        # payType=0（オンライン決済）：指定できません
        # payType=1（バーコード決済（店舗スキャン型））、3（バーコード決済（消費者スキャン型））：指定任意
        # payType=2（オンライン決済（V2））：指定できません
        # @param:: cancel_reason キャンセル理由詳細
        #
        def cancel_reason=(cancel_reason)
          @cancel_reason = cancel_reason
        end


      end
    end
  end
end
