# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/response_base_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：Tenpay、コマンド名：返金の応答Dtoクラス
      #
      # @author:: VeriTrans Inc.
      #
      class TenpayRefundResponseDto < Veritrans::Tercerog::Mdk::ResponseBaseDto

        #
        # ===決済サービスタイプを取得する
        # 決済サービスの区分を返却します。
        # - "tenpay"： Tenpay決済
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスタイプを設定する
        # @param:: service_type 決済サービスタイプ
        #
        def service_type=(service_type)
          @service_type = service_type
        end

        #
        # ===処理結果コードを取得する
        # 返金請求処理後、応答電文に含まれる値。
        # 以下の処理結果のいずれかが格納される
        # - success：正常終了
        # - failure：異常終了
        # - pending：保留状態
        # @return:: 処理結果コード
        #
        def mstatus
          @mstatus = nil unless instance_variable_defined?(:@mstatus)
          @mstatus
        end

        #
        # ===処理結果コードを設定する
        # @param:: mstatus 処理結果コード
        #
        def mstatus=(mstatus)
          @mstatus = mstatus
        end

        #
        # ===詳細結果コードを取得する
        # 処理結果を詳細に表すコードを返却します。
        # 
        # 4桁ずつ4つのブロックで構成され、各ブロックでサービス毎の処理結果を表します。
        # @return:: 詳細結果コード
        #
        def v_result_code
          @v_result_code = nil unless instance_variable_defined?(:@v_result_code)
          @v_result_code
        end

        #
        # ===詳細結果コードを設定する
        # @param:: v_result_code 詳細結果コード
        #
        def v_result_code=(v_result_code)
          @v_result_code = v_result_code
        end

        #
        # ===残高を取得する
        # 残高を返します。
        # @return:: 残高
        #
        def balance
          @balance = nil unless instance_variable_defined?(:@balance)
          @balance
        end

        #
        # ===残高を設定する
        # @param:: balance 残高
        #
        def balance=(balance)
          @balance = balance
        end

        #
        # ===返金金額(外貨)を取得する
        # 返金金額(外貨)を返却します。
        # ※mstatus=failureの場合は設定されません。
        # ※serviceOptionType="barcode"の場合に返戻。
        # @return:: 返金金額(外貨)
        #
        def foreign_amount
          @foreign_amount = nil unless instance_variable_defined?(:@foreign_amount)
          @foreign_amount
        end

        #
        # ===返金金額(外貨)を設定する
        # @param:: foreign_amount 返金金額(外貨)
        #
        def foreign_amount=(foreign_amount)
          @foreign_amount = foreign_amount
        end

        #
        # ===通貨コード(外貨)を取得する
        # 通貨コード(外貨)を返却します。
        # ※mstatus=failureの場合は設定されません。
        # ※serviceOptionType="barcode"の場合に返戻。
        # @return:: 通貨コード(外貨)
        #
        def foreign_amount_currency
          @foreign_amount_currency = nil unless instance_variable_defined?(:@foreign_amount_currency)
          @foreign_amount_currency
        end

        #
        # ===通貨コード(外貨)を設定する
        # @param:: foreign_amount_currency 通貨コード(外貨)
        #
        def foreign_amount_currency=(foreign_amount_currency)
          @foreign_amount_currency = foreign_amount_currency
        end

        #
        # ===エラーメッセージを取得する
        # 処理結果に対するメッセージを返却します。
        # @return:: エラーメッセージ
        #
        def merr_msg
          @merr_msg = nil unless instance_variable_defined?(:@merr_msg)
          @merr_msg
        end

        #
        # ===エラーメッセージを設定する
        # @param:: merr_msg エラーメッセージ
        #
        def merr_msg=(merr_msg)
          @merr_msg = merr_msg
        end

        #
        # ===電文IDを取得する
        # @return:: 電文ID
        #
        def march_txn
          @march_txn = nil unless instance_variable_defined?(:@march_txn)
          @march_txn
        end

        #
        # ===電文IDを設定する
        # @param:: march_txn 電文ID
        #
        def march_txn=(march_txn)
          @march_txn = march_txn
        end

        #
        # ===取引IDを取得する
        # @return:: 取引ID
        #
        def order_id
          @order_id = nil unless instance_variable_defined?(:@order_id)
          @order_id
        end

        #
        # ===取引IDを設定する
        # @param:: order_id 取引ID
        #
        def order_id=(order_id)
          @order_id = order_id
        end

        #
        # ===取引毎に付くIDを取得する
        # @return:: 取引毎に付くID
        #
        def cust_txn
          @cust_txn = nil unless instance_variable_defined?(:@cust_txn)
          @cust_txn
        end

        #
        # ===取引毎に付くIDを設定する
        # @param:: cust_txn 取引毎に付くID
        #
        def cust_txn=(cust_txn)
          @cust_txn = cust_txn
        end

        #
        # ===MDKバージョンを取得する
        # 電文のバージョン番号を返却します。
        # @return:: MDKバージョン
        #
        def txn_version
          @txn_version = nil unless instance_variable_defined?(:@txn_version)
          @txn_version
        end

        #
        # ===MDKバージョンを設定する
        # @param:: txn_version MDKバージョン
        #
        def txn_version=(txn_version)
          @txn_version = txn_version
        end


        #
        # ===PayNowIDオブジェクトを取得する
        # @return:: PayNowIDオブジェクト
        #
        def pay_now_id_response
          @pay_now_id_response = nil unless instance_variable_defined?(:@pay_now_id_response)
          @pay_now_id_response
        end

        #
        # ===PayNowIDオブジェクトを設定する
        # @param:: pay_now_id_response PayNowIDオブジェクト
        #
        def pay_now_id_response=(pay_now_id_response)
          @pay_now_id_response = pay_now_id_response
        end

      end
    end
  end
end
