# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/abstract_payment_request_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：UPOP、コマンド名：与信の要求Dtoクラス
      #
      # @author:: VeriTrans Inc.
      #
      class UpopAuthorizeRequestDto < Veritrans::Tercerog::Mdk::AbstractPaymentRequestDto

        #
        # ===コンストラクタ
        #
        def initialize
          @service_type = SERVICE_TYPE
          @service_command = SERVICE_COMMAND
        end


        #
        # 決済サービスタイプ
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_TYPE = "upop"

        #
        # 決済サービスコマンド
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_COMMAND = "Authorize"


        #
        # ===決済サービスタイプを取得する
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスコマンドを取得する
        # @return:: 決済サービスコマンド
        #
        def service_command
          @service_command = nil unless instance_variable_defined?(:@service_command)
          @service_command
        end

        #
        # ===取引IDを取得する
        # - マーチャント側で取引を一意に表す注文管理IDを指定します。
        # - 申込処理ごとに一意である必要があります。
        # - 半角英数字、“-”（ハイフン）、“_”（アンダースコア）も使用可能です。
        # @return:: 取引ID
        #
        def order_id
          @order_id = nil unless instance_variable_defined?(:@order_id)
          @order_id
        end

        #
        # ===取引IDを設定する
        # - マーチャント側で取引を一意に表す注文管理IDを指定します。
        # - 申込処理ごとに一意である必要があります。
        # - 半角英数字、“-”（ハイフン）、“_”（アンダースコア）も使用可能です。
        # @param:: order_id 取引ID
        #
        def order_id=(order_id)
          @order_id = order_id
        end

        #
        # ===決済金額を取得する
        # 決済金額（日本円）を指定します。
        # 1 以上 999,999,999,999 以下
        # @return:: 決済金額
        #
        def amount
          @amount = nil unless instance_variable_defined?(:@amount)
          @amount
        end

        #
        # ===決済金額を設定する
        # 決済金額（日本円）を指定します。
        # 1 以上 999,999,999,999 以下
        # @param:: amount 決済金額
        #
        def amount=(amount)
          @amount = amount
        end

        #
        # ===売上フラグを取得する
        # - true : 与信同時売上
        # - false: 与信のみ
        # ※ 未指定の場合は、false:与信のみ。
        # @return:: 売上フラグ
        #
        def with_capture
          @with_capture = nil unless instance_variable_defined?(:@with_capture)
          @with_capture
        end

        #
        # ===売上フラグを設定する
        # - true : 与信同時売上
        # - false: 与信のみ
        # ※ 未指定の場合は、false:与信のみ。
        # @param:: with_capture 売上フラグ
        #
        def with_capture=(with_capture)
          @with_capture = with_capture
        end

        #
        # ===決済結果戻り先URLを取得する
        # 決済完了後に、店舗側へ遷移を戻すためのURLを指定します。
        # - 半角256文字以内
        # @return:: 決済結果戻り先URL
        #
        def term_url
          @term_url = nil unless instance_variable_defined?(:@term_url)
          @term_url
        end

        #
        # ===決済結果戻り先URLを設定する
        # 決済完了後に、店舗側へ遷移を戻すためのURLを指定します。
        # - 半角256文字以内
        # @param:: term_url 決済結果戻り先URL
        #
        def term_url=(term_url)
          @term_url = term_url
        end

        #
        # ===消費者IPアドレスを取得する
        # 消費者側のIPアドレスを指定します。
        # ※ IPV6の形式も対応しています。
        # @return:: 消費者IPアドレス
        #
        def customer_ip
          @customer_ip = nil unless instance_variable_defined?(:@customer_ip)
          @customer_ip
        end

        #
        # ===消費者IPアドレスを設定する
        # 消費者側のIPアドレスを指定します。
        # ※ IPV6の形式も対応しています。
        # @param:: customer_ip 消費者IPアドレス
        #
        def customer_ip=(customer_ip)
          @customer_ip = customer_ip
        end


      end
    end
  end
end
