# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/abstract_payment_virtualacc_request_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：銀行振込決済、コマンド名：決済申込の要求Dtoクラス
      #
      # @author:: VeriTrans Inc.
      #
      class VirtualaccAuthorizeRequestDto < Veritrans::Tercerog::Mdk::AbstractPaymentVirtualaccRequestDto

        #
        # ===コンストラクタ
        #
        def initialize
          @service_type = SERVICE_TYPE
          @service_command = SERVICE_COMMAND
        end


        #
        # 決済サービスタイプ
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_TYPE = "virtualacc"

        #
        # 決済サービスコマンド
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_COMMAND = "Authorize"


        #
        # ===決済サービスタイプを取得する
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスコマンドを取得する
        # @return:: 決済サービスコマンド
        #
        def service_command
          @service_command = nil unless instance_variable_defined?(:@service_command)
          @service_command
        end

        #
        # ===サービスオプションタイプを取得する
        # @return:: サービスオプションタイプ
        #
        def service_option_type
          @service_option_type = nil unless instance_variable_defined?(:@service_option_type)
          @service_option_type
        end

        #
        # ===サービスオプションタイプを設定する
        # - "resona":りそな
        # 
        # @param:: service_option_type サービスオプションタイプ
        #
        def service_option_type=(service_option_type)
          @service_option_type = service_option_type
        end

        #
        # ===取引IDを取得する
        # @return:: 取引ID
        #
        def order_id
          @order_id = nil unless instance_variable_defined?(:@order_id)
          @order_id
        end

        #
        # ===取引IDを設定する
        # - マーチャント側で取引を一意に表す注文管理IDを指定します。
        # - 申込処理ごとに一意である必要があります。
        # - 半角英数字、“-”（ハイフン）、“_”（アンダースコア）も使用可能です。
        # @param:: order_id 取引ID
        #
        def order_id=(order_id)
          @order_id = order_id
        end

        #
        # ===決済金額を取得する
        # @return:: 決済金額
        #
        def amount
          @amount = nil unless instance_variable_defined?(:@amount)
          @amount
        end

        #
        # ===決済金額を設定する
        # 決済金額を指定します。
        # - 1 以上かつ 999999999999(12桁) 以下
        # @param:: amount 決済金額
        #
        def amount=(amount)
          @amount = amount
        end

        #
        # ===登録時振込人名を取得する
        # @return:: 登録時振込人名
        #
        def entry_transfer_name
          @entry_transfer_name = nil unless instance_variable_defined?(:@entry_transfer_name)
          @entry_transfer_name
        end

        #
        # ===登録時振込人名を設定する
        # @param:: entry_transfer_name 登録時振込人名
        #
        def entry_transfer_name=(entry_transfer_name)
          @entry_transfer_name = entry_transfer_name
        end

        #
        # ===登録時振込番号を取得する
        # @return:: 登録時振込番号
        #
        def entry_transfer_number
          @entry_transfer_number = nil unless instance_variable_defined?(:@entry_transfer_number)
          @entry_transfer_number
        end

        #
        # ===登録時振込番号を設定する
        # @param:: entry_transfer_number 登録時振込番号
        #
        def entry_transfer_number=(entry_transfer_number)
          @entry_transfer_number = entry_transfer_number
        end

        #
        # ===振込期限を取得する
        # @return:: 振込期限
        #
        def transfer_expired_date
          @transfer_expired_date = nil unless instance_variable_defined?(:@transfer_expired_date)
          @transfer_expired_date
        end

        #
        # ===振込期限を設定する
        # YYYYMMDD
        # @param:: transfer_expired_date 振込期限
        #
        def transfer_expired_date=(transfer_expired_date)
          @transfer_expired_date = transfer_expired_date
        end

        #
        # ===口座番号を取得する
        # @return:: 口座番号
        #
        def account_number
          @account_number = nil unless instance_variable_defined?(:@account_number)
          @account_number
        end

        #
        # ===口座番号を設定する
        # 口座管理方式が0:実口座の場合は利用不可項目となります。
        # ⇒マーチャント情報に紐づく実口座の口座番号が指定されます。
        # 口座管理方式が1:バーチャル口座の場合は必須項目となります。
        # ⇒PayNow側で払い出された口座番号が指定されます。
        # @param:: account_number 口座番号
        #
        def account_number=(account_number)
          @account_number = account_number
        end

        #
        # ===口座管理方式を取得する
        # @return:: 口座管理方式
        #
        def account_manage_type
          @account_manage_type = nil unless instance_variable_defined?(:@account_manage_type)
          @account_manage_type
        end

        #
        # ===口座管理方式を設定する
        # - 0 : 実口座
        # - 1: バーチャル口座
        # @param:: account_manage_type 口座管理方式
        #
        def account_manage_type=(account_manage_type)
          @account_manage_type = account_manage_type
        end

        #
        # ===支店コードを取得する
        # @return:: 支店コード
        #
        def branch_code
          @branch_code = nil unless instance_variable_defined?(:@branch_code)
          @branch_code
        end

        #
        # ===支店コードを設定する
        # 口座管理方式が0:実口座の場合は利用不可項目となります。
        # 口座管理方式が1:バーチャル口座の場合は必須項目となります。
        # ⇒PayNow側でバーチャル口座情報マスタから取得した支店コードが指定されます。
        # @param:: branch_code 支店コード
        #
        def branch_code=(branch_code)
          @branch_code = branch_code
        end

        #
        # ===口座名義を取得する
        # @return:: 口座名義
        #
        def account_name
          @account_name = nil unless instance_variable_defined?(:@account_name)
          @account_name
        end

        #
        # ===口座名義を設定する
        # 口座管理方式が0:実口座の場合は利用不可項目となります。
        # 口座管理方式が1:バーチャル口座の場合は必須項目となります。
        # ⇒PayNow側で払い出された口座名義が指定されます。
        # @param:: account_name 口座名義
        #
        def account_name=(account_name)
          @account_name = account_name
        end


      end
    end
  end
end
