# -*- encoding: utf-8 -*-
#= mdk_logger.rb - MDK Library ロガークラス
#
#Copyright:: VeriTrans Inc.
#Authors::   VeriTrans Inc.
#

old_verbose = $VERBOSE
$VERBOSE = false
begin
  require 'log4r'
  require 'log4r/configurator'
  require 'log4r/yamlconfigurator'
rescue LoadError
  require 'rubygems'
  require 'log4r'
  require 'log4r/configurator'
  require 'log4r/yamlconfigurator'
ensure
  $VERBOSE = old_verbose
end

module Veritrans
  module Tercerog
    module Mdk

      #
      # MdkLogger クラス
      #    Mdkで利用するデフォルトロガークラスを定義します。
      #
      class MdkLogger < Log4r::Logger

        #
        # ===コンストラクタ
        # @param:: _fullname ログ出力クラス識別名
        # @param:: config_file_name ログ設定ファイル名
        #
        def initialize(_fullname, config_file_name=nil)

          old_verbose = $VERBOSE
          $VERBOSE = false
          begin
            unless config_file_name
              config_file_name = "#{File.expand_path(File.dirname(__FILE__))}/../../tg_mdk_log4r.yaml"
              if not File.exist?(config_file_name)
                config_file_name = "#{File.expand_path(File.dirname(__FILE__))}/../../tg_mdk_log4r.xml"
              end
            end

            if config_file_name.end_with?(".xml")
              Log4r::Configurator.load_xml_file(config_file_name)
            else
              Log4r::YamlConfigurator.load_yaml_file(config_file_name)
            end

            super(_fullname)
            self.trace = true
          ensure
            $VERBOSE = old_verbose
          end
        end

      end
    end
  end
end

